@@ -16,9 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-
-#include "tlf.h"
-#include <string.h>
+#ifndef ADDAREA_H
+#define ADDAREA_H
 
 int add_callarea( void);
+
+#endif /* ADDAREA_H */
