@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2013           Ervin Hegedüs - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,22 +17,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include <string.h>
-#include <stdlib.h>
-#include <curses.h>
-#include "searchcallarray.h"
-#include "getctydata.h"
-#include "zone_nr.h"
-#include "getpx.h"
-#include "tlf.h"
-#include "paccdx.h"
-#include "addmult.h"
-#include "lancode.h"
-#include "tlf.h"
-
-
+#ifndef ADDCALL_H
+#define ADDCALL_H
 
 int addcall(void);
 int addcall2(void);
 int get_band (char *logline);
+
+#endif /* ADDCALL_H */
