@@ -16,10 +16,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include <string.h>
-#include "tlf.h"
-
+#ifndef ADDPFX_H
+#define ADDPFX_H
 
 int add_pfx(char *pxstr);
+int GetNrOfPfx_once();
+int GetNrOfPfx_multiband();
+int GetNrOfPfx_OnBand(int bandindex);
+void InitPfx();
 
+#endif /* ADDPFX_H */
