@@ -23,21 +23,19 @@
 	 *--------------------------------------------------------------*/
 
 #include "autocq.h"
+#include "tlf.h"
 #include "printcall.h"
 #include "clear_display.h"
 #include "sendbuf.h"
 #include "stoptx.h"
 #include "cw_utils.h"
-#include <string.h>
-#include <curses.h>
+#include "ui_utils.h"
 
 int play_file(char *audiofile);
 
 /* FIXME: Needs refactorization and cleanup of logic */
 int auto_cq(void)
 {
-
-    extern int use_rxvt;
     extern char mode[];
     extern char message[][80];
     extern char ph_message[14][80];
@@ -54,7 +52,6 @@ int auto_cq(void)
 
     strcpy(mode, "AUTO_CQ ");
     clear_display();
-    nodelay(stdscr, TRUE);
     while (delayval == 0) {
 	if (trxmode == CWMODE || trxmode == DIGIMODE) {
 	    sendmessage(message[11]);
@@ -63,10 +60,7 @@ int auto_cq(void)
 
 	mvprintw(12, 29 + strlen(hiscall), "");
 
-	if (use_rxvt == 0)
-	    attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-	else
-	    attron(COLOR_PAIR(NORMCOLOR));
+	attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
 	delayval = cqdelay;
 
@@ -77,10 +71,9 @@ int auto_cq(void)
 	    message_time = (long) (1200.0 / realspeed) * cw_message_len;
 	    for (j = 0; j < 10; j++) {
 		usleep(message_time * 100);
-		inchar = getch();
-		if (inchar > 0)
-		    letter = inchar;
+		inchar = key_poll();
 		if (inchar > 0) {
+		    letter = inchar;
 		    stoptx();
 		    break;
 		}
@@ -97,7 +90,7 @@ int auto_cq(void)
 	    usleep(500000);
 
 	    if (inchar < 0)
-		inchar = getch();
+		inchar = key_poll();
 	    letter = inchar;
 	    if (inchar > 0)
 		break;
@@ -113,17 +106,13 @@ int auto_cq(void)
 
     clear_display();
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
     if (letter > 96 && letter < 123)
 	letter -= 32;
 
     mvprintw(12, 29, "             ");
     printcall();
-    nodelay(stdscr, FALSE);
     if (inchar == 27)
 	return (27);
     else
