@@ -1,7 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
- *                         2011 Thomas Beierlein <tb@forth-ev.de>
+ *               2011, 2014     Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,24 @@
  */
 
 #include "background_process.h"
+#include "tlf.h"
+#include "time_update.h"
+#include "write_keyer.h"
+#include "sendbuf.h"
+#include "lancode.h"
+#include "splitscreen.h"
+#include "log_to_disk.h"
+#include "getctydata.h"
 #include "set_tone.h"
 #include "rtty.h"
+#include "fldigixmlrpc.h"
+#include "get_time.h"
+#include "qsonr_to_str.h"
+#include "gettxinfo.h"
+#include "qtc_log.h"
+#include "qtcutil.h"
+#include "searchlog.h"
+#include <glib.h>
 
 extern int stop_backgrnd_process;
 extern int this_second;
@@ -45,6 +61,9 @@ extern int timeoffset;
 extern char call[];
 extern int trxmode;
 extern int keyerport;
+extern int trx_control;
+
+int cw_simulator(void);
 
 void *background_process(void *ptr)
 {
@@ -55,6 +74,7 @@ void *background_process(void *ptr)
     static int i, t;
     static char prmessage[256];
     static int lantimesync = 0;
+    static int fldigi_rpc_cnt;
 
     int n;
 
@@ -69,6 +89,7 @@ void *background_process(void *ptr)
 	    sleep(1);
 	}
 
+
 	usleep(10000);
 
 	if (packetinterface != 0) {
@@ -80,6 +101,22 @@ void *background_process(void *ptr)
 	    && (keyerport == MFJ1278_KEYER || keyerport == GMFSK))
 	    rx_rtty();
 
+	/*
+	 * calling Fldigi XMLRPC method, which reads the Fldigi's carrier
+	 * this function helps to show the correct freq of the RIG: reads
+	 * the carrier value from Fldigi, and stores in a variable; then
+	 * it readable by fldigi_get_carrier()
+	 * only need at every 2nd cycle
+	 * see fldigixmlrpc.[ch]
+	 */
+	if (trxmode == DIGIMODE && keyerport == GMFSK && trx_control == 1) {
+	    if (fldigi_rpc_cnt == 2) {
+		fldigi_xmlrpc_get_carrier();
+		fldigi_rpc_cnt = 0;
+	    }
+	    fldigi_rpc_cnt++;
+	}
+
 	if (stop_backgrnd_process == 0) {
 	    write_keyer();
 	    cw_simulator();
@@ -132,6 +169,21 @@ void *background_process(void *ptr)
 		    log_to_disk(true);
 		    break;
 
+		case QTCRENTRY:
+
+		    store_recv_qtc(lan_message+2);
+		    break;
+
+		case QTCSENTRY:
+
+		    store_sent_qtc(lan_message+2);
+		    break;
+
+		case QTCFLAG:
+
+		    parse_qtc_flagline(lan_message+2);
+		    break;
+
 		case CLUSTERMSG:
 		    strncpy(prmessage, lan_message + 2, 80);
 		    if (strstr(prmessage, call) != NULL)	// alert for cluster messages
@@ -219,10 +271,8 @@ void *background_process(void *ptr)
 int cw_simulator(void)
 {
 
-    extern char callmasterarray[MAX_CALLMASTER][14];
     extern int simulator;
     extern int simulator_mode;
-    extern char buffer[];
     extern int simulator_seed;
     extern char simulator_tone[5];
     extern char tonestr[5];
@@ -233,7 +283,6 @@ int cw_simulator(void)
     static int callnumber;
     char callcpy[80];
     static int x;
-    char datacpy[160];
 
     if (simulator == 0)
 	return (-1);
@@ -304,10 +353,8 @@ int cw_simulator(void)
 	if (callnumber >= 27000)
 	    callnumber -= 27000;
 
-	strcpy(buffer, callmasterarray[callnumber]);
-	sendbuf();
+	sendmessage(CALLMASTERARRAY(callnumber));
 	write_keyer();
-	buffer[0] = '\0';
 	simulator_mode = 0;
 
 	strcpy(tonestr, tonecpy);
@@ -316,22 +363,19 @@ int cw_simulator(void)
 
     if (simulator_mode == 2) {
 
+	char *str;
 	strcpy(tonecpy, tonestr);
 	strcpy(tonestr, simulator_tone);
 	write_tone();
 
-	strcpy(callcpy, callmasterarray[callnumber]);
+	strcpy(callcpy, CALLMASTERARRAY(callnumber));
 
 	x = getctydata(callcpy);
 
-	buffer[0] = '\0';
-	strcat(buffer, "TU 5NN ");
+	str = g_strdup_printf("TU 5NN %2s", zone_export);
+	sendmessage(str);
+	g_free(str);
 
-	strncpy(datacpy, zone_export, 2);
-	strncat(buffer, datacpy, 2);
-
-	sendbuf();
-	buffer[0] = '\0';
 	simulator_mode = 0;
 	write_keyer();
 
@@ -341,23 +385,20 @@ int cw_simulator(void)
     }
     if (simulator_mode == 3) {
 
+	char *str;
+
 	strcpy(tonecpy, tonestr);
 	strcpy(tonestr, simulator_tone);
 	write_tone();
 
-	strcpy(callcpy, callmasterarray[callnumber]);
+	strcpy(callcpy, CALLMASTERARRAY(callnumber));
 	x = getctydata(callcpy);
 
-	buffer[0] = '\0';
-	strcat(buffer, "DE ");
-	strcat(buffer, callmasterarray[callnumber]);
-	strcat(buffer, " TU 5NN ");
+	str = g_strdup_printf("DE %s TU 5NN %s",
+		CALLMASTERARRAY(callnumber), zone_export);
+	sendmessage(str);
+	g_free(str);
 
-	strncpy(datacpy, zone_export, 2);
-	strncat(buffer, datacpy, 2);
-
-	sendbuf();
-	buffer[0] = '\0';
 	simulator_mode = 0;
 	write_keyer();
 
