@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2014           Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,17 +17,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include "time_update.h"
-#include "write_keyer.h"
-#include "sendbuf.h"
-#include "tlf.h"
-#include "set_tone.h"
-#include "lancode.h"
-#include "splitscreen.h"
-#include "log_to_disk.h"
-#include "getctydata.h"
+#ifndef BACKGROUND_PROCESS_H
+#define BACKGROUND_PROCESS_H
 
 void *background_process(void *);
-int cw_simulator(void);
 
+#endif /* end of include guard: BACKGROUND_PROCESS_H */
