@@ -23,7 +23,8 @@
 #include "getctydata.h"
 #include "showinfo.h"
 #include "searchlog.h"
-#include "onechar.h"
+#include "ui_utils.h"
+#include "qtcvars.h"
 
 #include <math.h>
 #include <glib.h>
@@ -33,15 +34,25 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <sys/time.h>
 
 #ifdef HAVE_LIBHAMLIB
 #include <hamlib/rig.h>
 #endif
 
-#define TOLERANCE 50
+#include "qtcutil.h"
+
+#define TOLERANCE 100 		/* spots with a QRG +/-TOLERANCE
+				   will be counted a s the same QRG */
+
+#define SPOT_COLUMN_WIDTH 22
+#define SPOT_FREQ_WIDTH 7
+#define SPOT_CALL_WIDTH SPOT_COLUMN_WIDTH-SPOT_FREQ_WIDTH-4
+				/* 3 space before and 1 after call */
+
 
 unsigned int bandcorner[NBANDS][2] =
-{{ 1800000, 2000000 },
+{{ 1800000, 2000000 },	// band bottom, band top
  { 3500000, 4000000 },
  { 7000000, 7300000 },
  { 10100000, 10150000 },
@@ -75,9 +86,8 @@ unsigned int ssbcorner[NBANDS] =
 
 pthread_mutex_t bm_mutex = PTHREAD_MUTEX_INITIALIZER;
 
-/** \brief sorted list of DX all recent spots
- *
- * a simple sorted linked list should do for a first start */
+/** \brief sorted list of all recent DX spots
+ */
 GList *allspots = NULL;
 
 /** \brief sorted list of filtered spots
@@ -94,12 +104,98 @@ bm_config_t bm_config = {
 };
 short	bm_initialized = 0;
 
+extern float freq;
+extern int trx_control;
 extern int bandinx;
 extern int trxmode;
 extern char thisnode;
+extern struct worked_t worked[];
+extern int contest;
 
-extern int call_band[];		/** \todo should not be public */
+char *qtc_format(char * call);
 
+gint cmp_freq(spot *a, spot *b);
+
+/*
+ * write bandmap spots to a file
+ */
+void bmdata_write_file(int last_bm_save_time) {
+
+    FILE * fp;
+    spot * sp;
+    GList *found;
+
+    if ((fp = fopen(".bmdata.dat", "w")) == NULL) {
+	attron(modify_attr(COLOR_PAIR(CB_DUPE)|A_BOLD));
+	mvprintw(13, 29, "can't open bandmap data file!");
+	refreshp();
+	return;
+    }
+    found = allspots;
+    fprintf(fp, "%d\n", last_bm_save_time);
+    while (found != NULL) {
+	sp = found->data;
+	fprintf(fp, "%s;%d;%d;%d;%c;%d;%d\n",
+		sp->call, sp->freq, sp->mode, sp->band,
+		sp->node, (int)sp->timeout, sp->dupe);
+	found = found->next;
+    }
+    fclose(fp);
+}
+
+/*
+ * read bandmap spots from file, put them to allspots list
+ */
+void bmdata_read_file() {
+    FILE * fp;
+    struct timeval tv;
+    int timediff, last_bm_save_time, fc;
+    char line[50], *token;
+    static int bmdata_parsed = 0;
+
+    if ((fp = fopen(".bmdata.dat", "r")) != NULL && bmdata_parsed == 0) {
+        bmdata_parsed = 1;
+	timediff = 0;
+	if (fgets(line, 50, fp)) {
+	    sscanf(line, "%d", &last_bm_save_time);
+	    gettimeofday(&tv, NULL);
+	    timediff = (int)tv.tv_sec - last_bm_save_time;
+	    while (fgets(line, 50, fp)) {
+	        spot *entry = g_new0(spot, 1);
+		fc = 0;
+		token = strtok (line, ";");
+		while (token != NULL)
+		{
+		    switch(fc) {
+			case 0:		entry -> call = g_strdup(token);
+					break;
+			case 1:		sscanf(token, "%d", &entry->freq);
+					break;
+			case 2:		sscanf(token, "%hhd", &entry->mode);
+					break;
+			case 3:		sscanf(token, "%hd", &entry->band);
+					break;
+			case 4:		sscanf(token, "%c", &entry->node);
+					break;
+			case 5:		sscanf(token, "%d", &entry->timeout);
+					entry->timeout -= timediff;
+					break;
+			case 6:		sscanf(token, "%hhd", &entry->dupe);
+					break;
+		    }
+		    fc++;
+		    token = strtok (NULL, ";");
+		}
+		if (entry->timeout > 0) {
+		    allspots = g_list_insert_sorted( allspots, entry, (GCompareFunc)cmp_freq);
+		} else {
+		    g_free(entry);
+		}
+	    }
+	}
+	fclose(fp);
+    }
+}
 
 /** \brief initialize bandmap
  *
@@ -117,6 +213,8 @@ void bm_init() {
 
     spots = g_ptr_array_sized_new( 128 );
 
+    bmdata_read_file();
+
     pthread_mutex_unlock( &bm_mutex );
 }
 
@@ -137,6 +235,7 @@ int freq2band(unsigned int freq) {
     return -1;		/* not in any band */
 }
 
+
 /** \brief guess mode based on frequency
  *
  * \return CWMODE, DIGIMODE or SSBMODE
@@ -207,6 +306,8 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
     GList *found;
     int band;
     char mode;
+    struct timeval tv;
+    static int last_bm_save_time = 0;
 
     /* add only HF spots */
     if (freq > 30000000)
@@ -283,6 +384,15 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
 	g_free (olddata);
     }
 
+    gettimeofday(&tv, NULL);
+    if (last_bm_save_time == 0) {
+	last_bm_save_time = (int)tv.tv_sec;
+    }
+    if ((int)tv.tv_sec > last_bm_save_time+10) {
+	last_bm_save_time = (int)tv.tv_sec;
+	bmdata_write_file(last_bm_save_time);
+    }
+
     pthread_mutex_unlock( &bm_mutex );
 }
 
@@ -295,6 +405,8 @@ void bandmap_age() {
  *   + if dead -> drop it from collection
  */
 
+    pthread_mutex_lock( &bm_mutex );
+
     GList *list = allspots;
 
     while (list) {
@@ -310,8 +422,11 @@ void bandmap_age() {
 	    }
 	}
     }
+
+    pthread_mutex_unlock( &bm_mutex );
 }
 
+
 int bm_ismulti( char * call) {
     return 0;
 }
@@ -321,20 +436,32 @@ int bm_ismulti( char * call) {
 
 int bm_isdupe( char *call, int band ) {
     int found = -1;
+    struct t_qtc_store_obj *qtc_obj;
 
     /* spot for warc bands are never dupes */
     if (IsWarcIndex(band))
 	return 0;
- 
+
     found = searchcallarray(call);
 
     if (found == -1)		/* new call */
 	return 0;
 
-    if (call_band[found] & inxes[band])
+    if (qtcdirection > 0) {
+        qtc_obj = qtc_get(call);
+	if (qtc_obj->total > 0 && qtc_obj->total < 10) {
+	    return 0;
+	}
+	if (qtc_obj->total == 0 && (qtc_obj->capable > 0)) {
+	    return 0;
+	}
+    }
+    if (worked[found].band & inxes[band]) {
 	return 1;
-    else
+    }
+    else {
 	return 0;
+    }
 }
 
 
@@ -348,7 +475,6 @@ void bm_show_info() {
     attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
     move(14,66);
     vline(ACS_VLINE,10);
-    mvprintw( 17, 68, "Spots: %3d", g_list_length(allspots));
 
     mvprintw (19, 68, "bands: %s", bm_config.allband ? "all" : "own");
     mvprintw (20,68, "modes: %s", bm_config.allmode ? "all" : "own");
@@ -375,6 +501,120 @@ void bm_show_info() {
 }
 
 
+/* helper function for bandmap display
+ * mark entries according to age, source and worked state. Mark new multis
+ * - new 	brigth blue
+ * - normal	blue
+ * - aged	brown
+ * - worked	small caps */
+void colorize_spot(spot *data) {
+    if (data -> timeout > SPOT_NORMAL)
+	attrset(COLOR_PAIR(CB_NEW)|A_BOLD);
+
+    else if (data -> timeout > SPOT_OLD)
+	attrset(COLOR_PAIR(CB_NORMAL));
+
+    else
+	attrset(COLOR_PAIR(CB_OLD));
+
+    if (bm_ismulti(data->call))
+	attron(A_STANDOUT);
+
+    if (data->dupe && bm_config.showdupes) {
+        attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
+        attroff(A_STANDOUT);
+    }
+}
+
+/* helper function for bandmap display
+ * convert dupes to lower case
+ * add QTC flags for WAE contest
+ */
+char *format_spot(spot *data) {
+    char *temp;
+    char *temp2;
+
+    if (qtcdirection > 0) {
+	temp = qtc_format(data->call);
+    }
+    else
+	temp = g_strdup(data->call);
+
+    if (data->dupe && bm_config.showdupes) {
+       temp2 = temp;
+       temp = g_ascii_strdown(temp2, -1);
+       g_free(temp2);
+    }
+    return temp;
+}
+
+
+/* helper function for bandmap display
+ * shows formatted spot on actual cursor position
+ */
+void show_spot(spot * data) {
+    attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
+    printw ("%7.1f %c ", (float)(data->freq/1000.),
+	    (data->node == thisnode ? '*' : data->node));
+
+    char *temp = format_spot(data);
+    colorize_spot(data);
+    printw ("%-12s", temp);
+    g_free(temp);
+}
+
+
+/* helper function for bandmap display
+ * shows spot on actual working frequency
+ */
+void show_spot_on_qrg(spot * data) {
+
+    printw ("%7.1f %c ", (data->freq/1000.),
+	    (data->node == thisnode ? '*' : data->node));
+
+    char *temp = format_spot(data);
+    printw ("%-12s", temp);
+    g_free(temp);
+}
+
+
+/* helper function for bandmap display
+ * advance to next spot position
+ */
+void next_spot_position (int *y, int *x) {
+    *y += 1;
+    if (*y == 24) {
+	*y = 14;
+	*x += SPOT_COLUMN_WIDTH;
+    }
+}
+
+/* helper function for bandmap display
+ * provide center frequency for display
+ *
+ * If we have a rig online, read the frequency from it.
+ * Otherwise calculate center frequency from band and mode
+ * as middle value of the band/mode corners.
+ */
+float bm_get_center(band, mode)
+{
+    float centerfrequency;
+
+    if (trx_control)
+	return freq;		/* return freq from rig */
+
+    /* calculate center frequency for current band and mode */
+    if (CWMODE == mode) {
+	centerfrequency = (bandcorner[band][0] + cwcorner[band]) / 2.;
+    } else if (SSBMODE == mode) {
+	centerfrequency = (ssbcorner[band] + bandcorner[band][1]) / 2.;
+    } else {
+	centerfrequency = (cwcorner[band] + ssbcorner[band]) / 2.;
+    }
+    return centerfrequency / 1000.;
+}
+
+
 void bandmap_show() {
 /*
  * display depending on filter state
@@ -399,8 +639,8 @@ void bandmap_show() {
  *
  * Allow selection of one of the spots (switches to S&P)
  * - Ctrl-G as known
- * - '.' and cursor plus 'Enter'
- * - Test mouseclick...
+ * - '.' and cursor plus 'Enter' \Todo
+ * - Test mouseclick..           \Todo
  *
  * '.' goes into map, shows help line above and supports
  * - cursormovement
@@ -411,11 +651,11 @@ void bandmap_show() {
 
     GList *list;
     spot *data;
-    int cols = 0;
     int curx, cury;
     int bm_x, bm_y;
     int i,j;
     short dupe;
+    float centerfrequency;
 
     if (!bm_initialized) {
 	bm_init();
@@ -427,10 +667,9 @@ void bandmap_show() {
      * - aging and
      * - filtering
      * furthermore do not allow call lookup as long as
-     * filter array is build anew */
-    pthread_mutex_lock( &bm_mutex );
+     * filtered spot array is build anew */
 
-    bandmap_age();			/* age entries in bandmap */
+    pthread_mutex_lock( &bm_mutex );
 
     /* make array of spots to display
      * filter spotlist according to settings */
@@ -447,11 +686,12 @@ void bandmap_show() {
 
 	/* if spot is allband or allmode is set or band or mode matches
 	 * actual one than add it to the filtered 'spot' array
+	 * drop spots on WARC bands if in contest mode
 	 */
 
 	dupe = bm_isdupe(data->call, data->band);
-
-	if ((bm_config.allband || (data->band == bandinx)) &&
+	if (    (!contest || !IsWarcIndex(data->band))         &&
+		(bm_config.allband || (data->band == bandinx)) &&
 		(bm_config.allmode || (data->mode == trxmode)) &&
 		(bm_config.showdupes || !dupe)) {
 
@@ -466,9 +706,8 @@ void bandmap_show() {
 
 
     /* afterwards display filtered list around own QRG +/- some offest
-     * (offset gets resest if we change frequency */
+     * (offset gets reset if we change frequency */
 
-    /** \todo Auswahl des Display Bereiches */
     getyx( stdscr, cury, curx);		/* remember cursor */
 
     /* start in line 14, column 0 */
@@ -488,57 +727,108 @@ void bandmap_show() {
 	    addch (' ');
     }
 
+    /* show info text */
     bm_show_info();
-    /** \fixme Darstellung des # Speichers */
 
-    for (i = 0; i < spots->len; i++)
-    {
+    /* split bandmap into two parts below and above current QRG.
+     * Give both both parts equal size.
+     * If there are less spots then reserved in the half
+     * give the remaining room to the other half.
+     *
+     * These results in maximized usage of the bandmap display while
+     * trying to keep the actual frequency in the center.
+     */
+    unsigned int below_qrg = 0;
+    unsigned int on_qrg = 0;
+    unsigned int startindex, stopindex;
+
+    centerfrequency = bm_get_center(bandinx, trxmode);
+
+    /* calc number of spots below your current QRG */
+    for (i = 0; i < spots->len; i++) {
 	data = g_ptr_array_index( spots, i );
 
-	attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
-	mvprintw (bm_y, bm_x, "%7.1f %c ", (float)(data->freq/1000.),
-		(data->node == thisnode ? '*' : data->node));
-
-	if (data -> timeout > SPOT_NORMAL)
-	    attrset(COLOR_PAIR(CB_NEW)|A_BOLD);
-
-	else if (data -> timeout > SPOT_OLD)
-	    attrset(COLOR_PAIR(CB_NORMAL));
-
+	if (data->freq < (centerfrequency*1000 - TOLERANCE))
+	    below_qrg++;
 	else
-	    attrset(COLOR_PAIR(CB_OLD));
-
-	if (bm_ismulti(data->call))
-	    attron(A_STANDOUT);
-
-       if (data->dupe) {
-	   if (bm_config.showdupes) {
-	       attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
-	       attroff(A_STANDOUT);
-	       printw ("%-12s", g_ascii_strdown(data->call, -1));
-	   }
-	}
-	else {
-	    printw ("%-12s", data->call);
-	}
-
-	attroff (A_BOLD);
-
-	bm_y++;
-	if (bm_y == 24) {
-	    bm_y = 14;
-	    bm_x += 22;
-	    cols++;
-	    if (cols > 2)
-		break;
-	}
+	    break;
     }
 
+    /* check if current QRG is on a spot */
+    if (below_qrg < spots->len) {
+	data = g_ptr_array_index( spots, below_qrg );
+
+	if (!(data->freq > centerfrequency*1000 + TOLERANCE))
+	    on_qrg = 1;
+    }
+
+    /* calc the index into the spot array of the first spot to show */
+    {
+	unsigned int max_below;
+	unsigned int above_qrg = spots->len - below_qrg - on_qrg;
+
+	if (above_qrg < 14) {
+	    max_below = 30 - above_qrg - 1;
+	}
+	else
+	    max_below = 15;
+
+	startindex = (below_qrg < max_below)? 0 : (below_qrg - max_below);
+    }
+
+    /* calculate the index+1 of the last spot to show */
+    stopindex  = (spots->len < startindex + 30 - (1 - on_qrg))
+	? spots->len
+	: (startindex + 30 - (1 - on_qrg));
+
+    /* correct calculations if we have no rig frequency to show */
+    if (trx_control == 0) {
+	if (on_qrg) {
+	    on_qrg = 0;
+	} else {
+	    stopindex += 1;
+	}
+	if (spots->len < stopindex)
+	    stopindex = spots->len;
+    }
+
+    /* show spots below QRG */
+    for (i = startindex; i < below_qrg; i++)
+    {
+	move (bm_y, bm_x);
+	show_spot(g_ptr_array_index( spots, i ));
+	next_spot_position(&bm_y, &bm_x);
+    }
+
+    /* show highlighted frequency marker or spot on QRG if rig control
+     * is active */
+    if (trx_control != 0) {
+	move (bm_y, bm_x);
+	attrset(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+	if (!on_qrg) {
+	    printw ("%7.1f   %s", centerfrequency,  "============");
+	}
+	else {
+	    show_spot_on_qrg(g_ptr_array_index( spots, below_qrg ));
+	}
+	next_spot_position(&bm_y, &bm_x);
+    }
+
+    /* show spots above QRG */
+    for (i = below_qrg + on_qrg; i < stopindex; i++)
+    {
+	move (bm_y, bm_x);
+	show_spot(g_ptr_array_index( spots, i ));
+	next_spot_position(&bm_y, &bm_x);
+    }
+
+    attroff (A_BOLD);
     move(cury, curx);			/* reset cursor */
 
     refreshp();
 }
 
+
 /** allow control of bandmap features
  */
 void bm_menu()
@@ -553,7 +843,7 @@ void bm_menu()
     mvprintw( 13, 0, "  Toggle <B>and, <M>ode or <D>upes filter");
     printw(" | any other - leave");
 
-    c = toupper( onechar());
+    c = toupper( key_get());
     switch (c) {
 	case 'B':
 	    bm_config.allband = 1 - bm_config.allband;
@@ -691,3 +981,41 @@ spot *bandmap_next(unsigned int upwards, unsigned int freq)
     return result;
 }
 
+/*
+ * copy string to buffer but truncate it to n characters
+ * If truncated show it by replacing last two chars by '..'
+ * The buffer has to be at least n+1 chars long.
+ */
+void str_truncate(char *buffer, char *string, int n) {
+    if (strlen(string) > n) {
+	g_strlcpy(buffer, string, n-1);   	/* truncate to n-2 chars */
+	strcat(buffer, "..");
+    }
+    else {
+	g_strlcpy(buffer, string, n+1); 	/* copy up to n chars */
+    }
+}
+
+/*
+ * format bandmap call output for WAE
+ * - prepare and return a temporary string from call and number of QTC's
+ *   (if any)
+ */
+char *qtc_format(char * call) {
+    char tcall[15];
+    char qtcflag;
+    struct t_qtc_store_obj *qtc_temp_ptr;
+
+    qtc_temp_ptr = qtc_get(call);
+    qtcflag = qtc_get_value(qtc_temp_ptr);
+
+    if (qtc_temp_ptr->total <= 0 && qtcflag == '\0') {
+	str_truncate(tcall, call, SPOT_CALL_WIDTH);
+    }
+    else {
+	str_truncate(tcall, call, SPOT_CALL_WIDTH-2);
+	sprintf(tcall + strlen(tcall), " %c", qtcflag);
+    }
+    return g_strdup(tcall);
+}
+
