@@ -24,6 +24,11 @@
      *--------------------------------------------------------------*/
 
 #include "calledit.h"
+#include "tlf.h"
+#include "ui_utils.h"
+#include "searchlog.h"
+#include "getctydata.h"
+#include "showinfo.h"
 
 void calledit(void)
 {
@@ -50,10 +55,10 @@ void calledit(void)
 	mvprintw(12, 29, "            ");
 	mvprintw(12, 29, hiscall);
 	mvprintw(12, 29 + b, "");
-	/* no refreshp() here as getch() calls wrefresh() for the 
+	/* no refreshp() here as getch() calls wrefresh() for the
 	 * panel with last output (whre the cursor should go */
 
-	i = onechar();
+	i = key_get();
 
 	if ((i == 161) || (i == 160))	// Ins / Del
 	    cnt++;
@@ -137,10 +142,10 @@ void calledit(void)
 
 	    if (((i >= 65) && (i <= 90)) || ((i >= 47) && (i <= 57))) {
 
+		call2[0] = '\0';
+
 		if (b <= 12) {
 		    strncpy(call1, hiscall, b);
-		}
-		if (b <= 12) {
 		    strncpy(call2, hiscall + b, strlen(hiscall) - (b - 1));
 		}
 
@@ -205,7 +210,7 @@ int insert_char(int curposition)
 
     while (ichr != 27) {
 
-	ichr = onechar();
+	ichr = key_get();
 
 	if ((ichr == 9) || (ichr == '\n') || (ichr == 127))
 	    break;		// leave insert mode
