@@ -16,15 +16,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include <curses.h>
-#include <string.h>
-#include "onechar.h"
-#include "searchlog.h"
-#include "getctydata.h"
-#include "showinfo.h"
+#ifndef CALLEDIT_H
+#define CALLEDIT_H
 
 void calledit(void);
 int insert_char(int);
 
-
+#endif /* CALLEDIT_H */
