@@ -1,7 +1,8 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2005 Rein Couperus <pa0r@eudxf.org>
- *               2009-2013 Thomas Beierlein <tb@forth-ev.de>
+ *               2009-2014 Thomas Beierlein <tb@forth-ev.de>
+ *               2013      Ervin Hegedüs - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +29,48 @@
 #include "changefreq.h"
 #include "bandmap.h"
 #include <glib.h>
+#include "show_help.h"
 #include "cw_utils.h"
+#include "qtcwin.h"
+#include "netkeyer.h"
+#include "nicebox.h"
+#include "tlf.h"
+#include "clear_display.h"
+#include "stoptx.h"
+#include "speedupndown.h"
+#include "sendbuf.h"
+#include "scroll_log.h"
+#include "addcall.h"
+#include "makelogline.h"
+#include "store_qso.h"
+#include "qsonr_to_str.h"
+#include "writeparas.h"
+#include "printcall.h"
+#include "time_update.h"
+#include "cleanup.h"
+#include "autocq.h"
+#include "sendspcall.h"
+#include "edit_last.h"
+#include "changepars.h"
+#include "deleteqso.h"
+#include "note.h"
+#include "prevqso.h"
+#include "getctydata.h"
+#include "showinfo.h"
+#include "searchlog.h"
+#include "calledit.h"
+#include "muf.h"
+#include "clusterinfo.h"
+#include "grabspot.h"
+#include "splitscreen.h"
+#include "showpxmap.h"
+#ifdef HAVE_LIBHAMLIB
+#include <hamlib/rig.h>
+#endif
+#include "lancode.h"
+#include "rtty.h"
+#include "ui_utils.h"
+#include "qtcvars.h"
 
 #define TUNE_UP 6	/* tune up for 6 s (no more than 10) */
 
@@ -43,7 +85,6 @@ char callinput(void)
 {
     extern int itumult;
     extern int wazmult;
-    extern int use_rxvt;
     extern int no_arrows;
     extern int isdupe;		// LZ3NY auto-b4 patch
     extern int contest;
@@ -53,7 +94,6 @@ char callinput(void)
     extern char hiscall[];
     extern char hiscall_sent[];
     extern char comment[];
-    extern char call[];
     extern int cqmode;
     extern int trxmode;
     extern char mode[];
@@ -63,10 +103,8 @@ char callinput(void)
     extern int cqdelay;
     extern char his_rst[];
     extern char backgrnd_str[];
-    extern int demode;
     extern int cluster;
     extern int announcefilter;
-    extern char buffer[];
     extern char message[][80];
     extern char ph_message[14][80];
     extern float freq;
@@ -109,10 +147,7 @@ char callinput(void)
     static int lastwindow;
 
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
     printcall();	/* print call input field */
     searchlog(hiscall);
@@ -122,7 +157,7 @@ char callinput(void)
 	printcall();
 
 	/* wait for next char pressed, but update time, cluster and TRX qrg */
-	nodelay(stdscr, TRUE);	/* main loop waiting for input */
+	/* main loop waiting for input */
 	x = -1;
 	while (x < 1) {
 
@@ -139,10 +174,9 @@ char callinput(void)
 	    /* make sure that the wrefresh() inside getch() shows the cursor
 	     * in the input field */
 	    wmove(stdscr, 12, 29 + strlen(hiscall));
-	    x = onechar();
+	    x = key_poll();
 
 	}
-	nodelay(stdscr, FALSE);
 
 
 	/* special handling of some keycodes if call field is empty */
@@ -184,15 +218,9 @@ char callinput(void)
 	    }
 
 	    if (x == '=' && *hiscall == '\0') {
-		strcat(buffer, lastcall);
-		strcat(buffer, " TU ");
-		sendbuf();
-		break;
-	    } else if (x == '=' && strlen(hiscall) != 0) {
-		/** \todo check if unreachable code */
-		strcat(buffer, lastcall);
-		strcat(buffer, " TU ");
-		sendbuf();
+		char *str = g_strdup_printf("%s TU ", lastcall);
+		sendmessage(str);
+		g_free(str);
 		break;
 	    }
 	}
@@ -219,6 +247,26 @@ char callinput(void)
 		break;
 	    }
 
+	case 17:	// CTRL+q
+	    {
+		if (qtcdirection == 1 || qtcdirection == 3) {	// in case of QTC=RECV or QTC=BOTH
+		    qtc_main_panel(RECV);
+		}
+		if (qtcdirection == 2) {			// in case of QTC=SEND
+		    qtc_main_panel(SEND);
+		}
+		x=155;
+		continue;
+	    }
+	case 19:	// CTRL+s
+	    {
+		if (qtcdirection == 2 || qtcdirection == 3) {	// in case of QTC=SEND ot QTC=BOTH
+		    qtc_main_panel(SEND);
+		}
+		x=155;
+		continue;
+	    }
+
 	case 155:		/* left */
 	    {
 		if (*hiscall != '\0') {
@@ -330,7 +378,7 @@ char callinput(void)
 			printcall();
 			refreshp();
 
-			x = onechar();
+			x = key_get();
 			if (x == 152) {
 			    speedup();
 			    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
@@ -493,10 +541,7 @@ char callinput(void)
 		    mvprintw(j, 0, backgrnd_str);
 		}
 
-		if (use_rxvt == 0)
-		    attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-		else
-		    attron(COLOR_PAIR(NORMCOLOR));
+		attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
 		mvprintw(12, 29, "            ");
 		mvprintw(12, 29, "");
@@ -535,7 +580,7 @@ char callinput(void)
 		break;
 	    }
 
-	case 176 ... 186:
+	case 176 ... 185:
 	    {
 		sendmessage(message[x - 162]);	/* alt-0 to alt-9 */
 
@@ -547,10 +592,7 @@ char callinput(void)
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
 
 		    if (cqmode == 0) {
-			if (demode == SEND_DE)
-			    strcat(buffer, "DE ");
-			strcat(buffer, call);		/* S&P */
-			sendbuf();
+			sendspcall();
 		    }
 		    else {
 			sendmessage(message[0]);	/* CQ */
@@ -560,9 +602,8 @@ char callinput(void)
 		    if (simulator != 0) {
 			simulator_mode = 1;
 		    }
-
-		    break;
 		} else {
+
 		    if (cqmode == 0)
 			play_file(ph_message[5]);	/* S&P */
 		    else
@@ -593,6 +634,7 @@ char callinput(void)
 	case 141:		/* F12 */
 	    {
 		x = auto_cq();
+		break;
 	    }
 	case '?':
             {
@@ -653,7 +695,7 @@ char callinput(void)
 		break;
 	    }
 	case 235:
-	    {			//alt-K     == ctrl-K
+	    {			//alt-K     => ctrl-K
 		x = 11;
 		break;
 	    }
@@ -758,7 +800,7 @@ char callinput(void)
 		    mvprintw(12, 29, "");
 		    refreshp();
 		    netkeyer(K_PTT, "1");	// ptt on
-		    x = onechar();	// any character to stop tuning
+		    x = key_get();	// any character to stop tuning
 		    if (x == 240)
 			netkeyer(K_PTT, "0");	// ptt off
 		    k_ptt = 0;
@@ -783,19 +825,15 @@ char callinput(void)
 		netkeyer(K_TUNE, buff);	// cw on
 		g_free(buff);
 
-		nodelay (stdscr, TRUE);
-
 		count = TUNE_UP / 0.25;
 
 		while (count != 0) {
 		    usleep( 250000 );
-		    if ((onechar()) != -1)	// any key pressed ?
+		    if ((key_poll()) != -1)	// any key pressed ?
 			break;
 		    count--;
 		}
 
-		nodelay (stdscr, FALSE);
-
 		netkeyer( K_ABORT, "");	// cw abort
 
 		mvprintw(0, 2, "%s", mode);
@@ -826,7 +864,7 @@ char callinput(void)
 		mvprintw(13, 29, "You want to leave tlf? (y/n): ");
 		while (x != 'n' && x != 'N') {
 
-		    x = onechar();
+		    x = key_get();
 
 		    if (x == 'y' || x == 'Y') {
 			writeparas();
@@ -958,7 +996,7 @@ char callinput(void)
 		    nicebox(14, 0, 5, 59, "Messages");
 
 		    refreshp();
-		    getchar();
+		    key_get();
 		    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 		    for (t = 0; t <= 6; t++)
 			mvprintw(14 + t, 0,
@@ -981,7 +1019,7 @@ char callinput(void)
 		instring[1] = '\0';
 		addch(x);
 		strcat(hiscall, instring);
-		if (cqmode == CQ && cwstart != 0 &&
+		if (cqmode == CQ && cwstart > 0 &&
 			trxmode == CWMODE && contest == 1) {
 		    /* early start keying after 'cwstart' characters but only
 		     * if input field contains at least one nondigit */
@@ -1005,6 +1043,17 @@ char callinput(void)
 
 	}
 
+	if (cqmode == CQ && cwstart < 0 && trxmode == CWMODE &&
+		contest == 1) {
+	    if (x == '\n') {
+		/* early start keying after 'Enter' but only if input field
+		 * contains at least two chars, one or more of it nondigit */
+		if (strlen(hiscall) >= 2 && !plain_number(hiscall)) {
+		    x = autosend();
+		}
+	    }
+	}
+
 	if ((x == '\n') || x == 32 || x == 9 || x == 11 || x == 44
 	    || x == 92)
 	    break;
@@ -1058,22 +1107,19 @@ int plain_number(char *str) {
  */
 int autosend()
 {
-    extern char buffer[];
     extern int early_started;
     extern int sending_call;
     extern char hiscall_sent[];
     extern char hiscall[];
-    extern char wkeyerbuffer[];
 
     GTimer *timer;
     double timeout, timeout_sent;
     int x;
     int char_sent;
 
-    strcpy(buffer, hiscall);
     early_started = 1;
     sending_call = 1;
-    sendbuf();
+    sendmessage(hiscall);
     sending_call = 0;
     strcpy(hiscall_sent, hiscall);
 
@@ -1085,7 +1131,6 @@ int autosend()
 
     x = -1;
     while ((x != 27) && (x != '\n')) {
-	nodelay(stdscr, TRUE);
 	x = -1;
 	while ((x == -1) && (g_timer_elapsed(timer, NULL) < timeout)) {
 
@@ -1104,10 +1149,9 @@ int autosend()
 	    /* make sure that the wrefresh() inside getch() shows the cursor
 	     * in the input field */
 	    wmove(stdscr, 12, 29 + strlen(hiscall));
-	    x = onechar();
+	    x = key_poll();
 
 	}
-	nodelay(stdscr, FALSE);
 
 	if (x == -1) { 		/* timeout */
 	    x = '\n';
@@ -1139,8 +1183,7 @@ int autosend()
 	    /* send it to cw */
 	    append[0] = x;
 	    append[1] = '\0';
-	    strcat(wkeyerbuffer, append);
-	    sendbuf();
+	    sendmessage(append);
 
 	    /* add char length to timeout */
 	    timeout += (1.2 / GetCWSpeed()) * getCWdots((char) x);
