@@ -24,10 +24,35 @@
 	 *--------------------------------------------------------------*/
 
 #include "changepars.h"
+#include "tlf.h"
+#include <glib.h>
+#include <termios.h>
 #include "sendbuf.h"
 #include "rules.h"
-#include <termios.h>
-#include <glib.h>
+#include "messagechange.h"
+#include "listmessages.h"
+#include "set_tone.h"
+#include "editlog.h"
+#include "logview.h"
+#include "show_help.h"
+#include "writecabrillo.h"
+#include "writeparas.h"
+#include "showpxmap.h"
+#include "setparameters.h"
+#include "muf.h"
+#include "parse_logcfg.h"
+#include "gettxinfo.h"
+#include "netkeyer.h"
+#include "splitscreen.h"
+#include "audio.h"
+#include "scroll_log.h"
+#include "readcalls.h"
+#include "readqtccalls.h"
+#ifdef HAVE_LIBHAMLIB
+#include <hamlib/rig.h>
+#endif
+#include "ui_utils.h"
+#include "qtcvars.h"
 
 #define MULTS_POSSIBLE(n) ((char *)g_ptr_array_index(mults_possible, n))
 
@@ -35,7 +60,6 @@ int debug_tty(void);
 
 int changepars(void)
 {
-    extern int use_rxvt;
     extern int cluster;
     extern int shortqsonr;
     extern int searchflg;
@@ -53,10 +77,9 @@ int changepars(void)
     extern int nopacket;
     extern int cqdelay;
     extern int ctcomp;
-    extern SCREEN *mainscreen;
     extern char *config_file;
     extern int miniterm;
-    extern char buffer[];
+    extern int total;
 
 #ifdef HAVE_LIBHAMLIB
     extern freq_t outfreq;
@@ -424,12 +447,7 @@ int changepars(void)
     case 49:
 	{
 	    if (keyerport == MFJ1278_KEYER) {
-		strcpy(buffer, "MODE CW,30");
-		buffer[7] = '\015';
-		buffer[8] = 'K';
-		buffer[9] = '\015';
-		buffer[10] = '\0';
-		sendbuf();
+		sendmessage("MODE CW\015K\015");
 	    }
 	    trxmode = CWMODE;
 
@@ -537,7 +555,7 @@ int changepars(void)
 
 	    x = 1;
 	    while (x) {
-		x = onechar();
+		x = key_get();
 
 		switch (x) {
 		case 156:{
@@ -567,10 +585,7 @@ int changepars(void)
 		}
 	    }
 
-	    if (use_rxvt == 0)
-		attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-	    else
-		attron(COLOR_PAIR(NORMCOLOR));
+	    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
 	    mvprintw(12, 29 + strlen(hiscall), "");
 	    break;
@@ -588,14 +603,22 @@ int changepars(void)
 		synclog(synclogfile);
 	    scroll_log();
 	    /** \todo register return value */
+	    total = 0;
 	    readcalls();
+	    if (qtcdirection > 0) {
+		readqtccalls();
+	    }
 	    clear_display();
 	    break;
 	}
     case 42:			/* RESCORE */
 	{
 	    /** \todo register return value */
+	    total = 0;
 	    readcalls();
+	    if (qtcdirection > 0) {
+		readqtccalls();
+	    }
 	    clear_display();
 	    break;
 	}
@@ -610,7 +633,7 @@ int changepars(void)
 
 	    x = 1;
 	    while (x) {
-		x = onechar();
+		x = key_get();
 
 		switch (x) {
 		case 156:{
@@ -668,12 +691,7 @@ int changepars(void)
 	}
     case 47:			/* RTTY Initialize mode (MFJ1278B controller) */
 	{
-	    strcpy(buffer, "MODE VB");
-	    buffer[7] = '\015';
-	    buffer[8] = 'K';
-	    buffer[9] = '\015';
-	    buffer[10] = '\0';
-	    sendbuf();
+	    sendmessage("MODE VB\015K\015");
 	    trxmode = DIGIMODE;
 
 	    break;
@@ -687,28 +705,35 @@ int changepars(void)
 	}
     case 50:			/* CHARS */
 	{
-	    mvprintw(13, 29, "Autosend: (0 (off), 2..5 chars) ?");
+	    mvprintw(13, 29, "Autosend: (0, 2..5, m)?");
 	    refreshp();
 	    x = 1;
 
 	    /* wait for correct input or ESC */
-	    while ((x != 0) && ((x < 2) || (x > 5)) ) {
-		x = onechar();
+	    while ((x != 0) && !((x >= 2) && (x <= 5)) && !(x == 'm' - '0') ) {
+		x = key_get();
 		if (x == 27)
 		    break;
 		x = x - '0';
 	    }
 
 	    /* remember new setting */
-	    if (x != 27)
-		cwstart = x;
+	    if (x != 27) {
+		if (x == 0 || (x >= 2 && x <= 5))
+		    cwstart = x;
+		else
+		    cwstart = -1;
+	    }
 
-	    if (cwstart)
-		mvprintw(13,29, "Autosend now: %1d                 ",
+	    if (cwstart > 0)
+		mvprintw(13,29, "Autosend now: %1d        ",
 			cwstart);
-	    else
-		mvprintw(13,29, "Autosend now: OFF                ");
-
+	    else {
+		if (cwstart < 0 )
+		    mvprintw(13,29, "Autosend now: Manual   ");
+	        else
+		    mvprintw(13,29, "Autosend now: OFF      ");
+	    }
 	    refreshp();
 	    break;
 
@@ -729,10 +754,7 @@ int changepars(void)
 
     refreshp();
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
     mvprintw(12, 29, "            ");
     mvprintw(12, 29, "");
@@ -746,8 +768,6 @@ int changepars(void)
 
 int networkinfo(void)
 {
-
-    extern int use_rxvt;
     extern int use_bandoutput;
     extern int recv_packets;
     extern int recv_error;
@@ -767,10 +787,7 @@ int networkinfo(void)
 
     clear();
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
-    else
-	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
     for (j = 0; j <= 24; j++)
 	mvprintw(j, 0,
@@ -810,12 +827,9 @@ int networkinfo(void)
     mvprintw(23, 22, " --- Press a key to continue --- ");
     refreshp();
 
-    getch();
+    (void)key_get();
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(C_LOG) | A_BOLD | A_STANDOUT);
-    else
-	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+    attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
     for (i = 0; i <= 24; i++)
 	mvprintw(i, 0,
 		 "                                                                                ");
@@ -830,8 +844,6 @@ int networkinfo(void)
 
 int multiplierinfo(void)
 {
-
-    extern int use_rxvt;
     extern int arrlss;
     extern int serial_section_mult;
     extern int sectn_mult;
@@ -842,21 +854,20 @@ int multiplierinfo(void)
 
     int j, k, vert, hor, cnt, found;
     char mprint[50];
-    char chmult[4];
-    char ch2mult[4];
 
     clear();
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
-    else
-	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
     for (j = 0; j <= 24; j++)
 	mvprintw(j, 0,
 		 "                                                                                ");
 
     if (arrlss == 1) {
+	int attributes;
+	char chmult[6];
+	char ch2mult[6];
+
 	mvprintw(2, 20, "ARRL SWEEPSTAKES -- REMAINING SECTIONS");
 	cnt = 0;
 	for (vert = 9; vert < 18; vert++) {
@@ -868,45 +879,36 @@ int multiplierinfo(void)
 		if (cnt >= mults_possible->len)
 		    break;
 
-		mprint[0] = '\0';
-		strcat(mprint, MULTS_POSSIBLE(cnt));
-		strcat(mprint, " ");
-		mprint[4] = '\0';
+		g_strlcpy(chmult, MULTS_POSSIBLE(cnt), sizeof(chmult));
 
+		/* check if in worked multis */
 		found = 0;
 		for (j = 0; j < multarray_nr; j++) {
-		    strcpy(chmult, MULTS_POSSIBLE(cnt));
-		    strcpy(ch2mult, mults[j]);
+		    g_strlcpy(ch2mult, mults[j], sizeof(ch2mult));
 
-		    if (ch2mult[2] == ' ')
-			ch2mult[2] = '\0';
-
-		    if (strcmp(ch2mult, chmult) == 0)
+		    if (strcmp(g_strchomp(ch2mult), chmult) == 0)
 			found = 1;
 		}
+
 		if (found == 1)
-
-		    if (use_rxvt == 0)
-			attron(COLOR_PAIR(C_HEADER) | A_BOLD |
-			       A_STANDOUT);
-		    else
-			attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-
-		else if (use_rxvt == 0)
-		    attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
+		    attributes = COLOR_PAIR(C_HEADER) | A_STANDOUT;
 		else
-		    attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+		    attributes = COLOR_PAIR(C_WINDOW) | A_STANDOUT;
 
-		if ((strlen(mprint) > 1) && (strcmp(mprint, "W ") != 0))
-		    mvprintw(vert, hor * 4, "%s", mprint);
+		attron(modify_attr(attributes));
+
+		g_strlcpy(mprint, MULTS_POSSIBLE(cnt), 5);
+		mvprintw(vert, hor * 4, "%s", mprint);
 
 		cnt++;
-
 	    }
 	}
     }
 
     if (serial_section_mult == 1 || (sectn_mult == 1 && arrlss != 1)) {
+	char * tmp;
+	int worked_at;
+
 	mvprintw(0, 30, "REMAINING SECTIONS");
 	cnt = 0;
 	for (vert = 2; vert < 22; vert++) {
@@ -917,72 +919,44 @@ int multiplierinfo(void)
 		if (cnt >= mults_possible->len)
 		    break;
 
-		mprint[0] = '\0';
-		strcat(mprint, MULTS_POSSIBLE(cnt));
-		if (strlen(mprint) == 0)
-		    break;
-		if (strlen(mprint) == 1)
-		    strcat(mprint, "   ");
-		if (strlen(mprint) == 2)
-		    strcat(mprint, "  ");
-		if (strlen(mprint) == 3)
-		    strcat(mprint, " ");
-		if (strlen(mprint) > 3)
-		    mprint[4] = '\0';
+		worked_at = 0;
 
-		for (k = 1; k <= MAX_MULTS; k++) {
-		    if (strstr(mults[k], MULTS_POSSIBLE(cnt)) != NULL)
+		/* lookup if already worked */
+		for (k = 0; k < multarray_nr; k++) {
+		    if (strstr(mults[k], MULTS_POSSIBLE(cnt)) != NULL) {
+			worked_at = mult_bands[k];
 			break;
+		    }
 		}
 
-		if ((mult_bands[k] & BAND160) != 0)
-		    strcat(mprint, "*");
-		else
-		    strcat(mprint, "-");
-		if ((mult_bands[k] & BAND80) != 0)
-		    strcat(mprint, "*");
-		else
-		    strcat(mprint, "-");
-		if ((mult_bands[k] & BAND40) != 0)
-		    strcat(mprint, "*");
-		else
-		    strcat(mprint, "-");
-		if ((mult_bands[k] & BAND20) != 0)
-		    strcat(mprint, "*");
-		else
-		    strcat(mprint, "-");
-		if ((mult_bands[k] & BAND15) != 0)
-		    strcat(mprint, "*");
-		else
-		    strcat(mprint, "-");
-		if ((mult_bands[k] & BAND10) != 0)
-		    strcat(mprint, "*");
-		else
-		    strcat(mprint, "-");
+		tmp = g_strndup(MULTS_POSSIBLE(cnt), 4);
+		sprintf(mprint, "%-4s", tmp);
+		g_free(tmp);
+
+		strcat(mprint, (worked_at & BAND160)?"*":"-");
+		strcat(mprint, (worked_at & BAND80)?"*":"-");
+		strcat(mprint, (worked_at & BAND40)?"*":"-");
+		strcat(mprint, (worked_at & BAND20)?"*":"-");
+		strcat(mprint, (worked_at & BAND15)?"*":"-");
+		strcat(mprint, (worked_at & BAND10)?"*":"-");
 
 		mprint[11] = '\0';
 		mvprintw(vert, 2 + hor * 11, "%s", mprint);
-		cnt++;
 
+		cnt++;
 	    }
 	}
     }
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
-    else
-	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+    attron(modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
     mvprintw(23, 22, " --- Press a key to continue --- ");
 
     refreshp();
 
-    getch();
+    (void)key_get();
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(C_LOG) | A_BOLD | A_STANDOUT);
-    else
-	attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+    attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
 
     for (j = 0; j <= 24; j++)
 	mvprintw(j, 0,
@@ -1149,7 +1123,7 @@ int debug_tty(void)
 
     mvprintw(23, 0, "done");
     refreshp();
-    i = getch();
+    (void)key_get();
 
 /* close the tty */
 
