@@ -25,9 +25,12 @@
 	 *
 	 *--------------------------------------------------------------*/
 #include "checklogfile.h"
+#include "tlf.h"
+#include <fcntl.h>
+#include <sys/stat.h>
 #include "startmsg.h"
 #include <glib.h>
-
+#include "ui_utils.h"
 
 /** Repair log file
  *
@@ -54,10 +57,21 @@ int repair_log(char *filename) {
     rc = system(cmd);
     g_free(cmd);
 
+    if (rc != 0) {
+	showmsg( "Could not backup logfile. Giving up!" );
+	return 1;
+    }
+
+
     showmsg( "Converting file to new format");
     infp = fopen(backupfile, "r");
     outfp = fopen(filename, "w");
 
+    if (!infp || !outfp) {
+	showmsg( "Could not convert logfile. Sorry!" );
+	return 1;
+    }
+
     while (fgets(buffer, sizeof(buffer), infp)) {
 
 	/* strip trailing whitespace (and newline) */
@@ -113,6 +127,9 @@ int checklogfile_new(char *filename)
 	    fclose(fp);
 	    return 0;
 	}
+
+	showstring( "Can not check log file: ", filename);
+	return 1;
     }
 
 
@@ -172,7 +189,7 @@ int checklogfile_new(char *filename)
 	showmsg( "Some log lines are too short (maybe an old log format)!" );
 	showmsg( "Shall I try to repair? Y/(N) " );
 	echo();
-	c =toupper( getch() );
+	c = toupper( key_get() );
 	noecho();
 
 	if (c != 'Y') {
