@@ -23,6 +23,9 @@
 	 *--------------------------------------------------------------*/
 
 #include "checkparameters.h"
+#include "tlf.h"
+#include "writeparas.h"
+#include "checklogfile.h"
 
 int checkparameters(void)
 {
