@@ -1,7 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
- *               2011i,2013     Thomas Beierlein <tb@forth-ev.de>
+ *               2011-2014      Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,104 +23,50 @@
 	 *          clusterinfo +  time update
 	 *--------------------------------------------------------------*/
 
+#include "tlf.h"
 #include "clusterinfo.h"
 #include "dxcc.h"
 #include "bandmap.h"
+#include "get_time.h"
+#include "getctydata.h"
+#include "printcall.h"
+#include "nicebox.h"
+#include "lancode.h"
+#include "searchcallarray.h"
+#include "ui_utils.h"
+
 #include <glib.h>
 #include <pthread.h>
 
+#define MAXMINUTES 30
+
 extern int bandinx;
 extern pthread_mutex_t spot_ptr_mutex;
 
 char *bandmap[MAX_SPOTS];
+int spotarray[MAX_SPOTS];		/* Array of indices into spot_ptr */
 
 int loadbandmap(void);
 int getclusterinfo(void);
 
-void clusterinfo(char *timestr)
+void clusterinfo(void)
 {
-    extern int use_rxvt;
     extern int cluster;
     extern char backgrnd_str[];
     extern float freq;
-    extern float mem;
     extern char band[9][4];
     extern int bandinx;
     extern int trx_control;
-    extern int showfreq;
-    extern int showscore_flag;
-    extern int spotarray[MAX_SPOTS];
     extern char spot_ptr[MAX_SPOTS][82];
-    extern int lan_active;
     extern float node_frequencies[MAXNODES];
     extern char thisnode;
-    extern int time_master;
-    extern int nroflines;
-    extern struct tm *time_ptr;
 
     int f, j, k;
     char inputbuffer[160] = "";
-    char time_buf[40] = "";
-    static int frcounter;
-    static int daysecs = 0;
-
-    /* show band, date and time */
-    attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
-    strncpy(time_buf, timestr, 8);
-    mvaddstr(12, 0, band[bandinx]);
-    mvprintw(12, 17, time_buf);
-
-    if (daysecs > 60) {		// update the date 1x per minute
-	daysecs = 0;
-	get_time();
-	strftime(time_buf, 60, "%d-%b-%y", time_ptr);
-	mvprintw(12, 7, time_buf);
-    } else {
-	daysecs++;
-    }
-
-    /* show frequency and frequency memory if rig control is active */
-    if (trx_control == 1) {
-
-	if (use_rxvt == 0)
-	    attron(COLOR_PAIR(C_LOG) | A_BOLD);
-	else
-	    attron(COLOR_PAIR(C_LOG));
-
-	if ((showfreq == 0) || (showscore_flag == 1))
-	    mvprintw(13, 68, "TRX: %7.1f", freq);
-
-	if (mem > 0.0)
-	    mvprintw(14, 68, "MEM: %7.1f", mem);
-	else
-	    mvprintw(14, 68, "            ");
-
-	if ((showfreq == 1) && (showscore_flag == 0)) {
-
-	    freq_display();
-	}
-    }
-
-    refreshp();
-
-    frcounter++;
-
-    /* broadcast frequency via LAN, act as time master if allowed */
-    if (frcounter >= 60) {	// every 60 seconds
-	frcounter = 0;
-	if (lan_active != 0) {
-	    send_freq(freq);
-	    if (time_master == 1)
-		send_time();
-	}
-    }
 
 
     /* cluster and bandmap display */
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
     mvprintw(12, 0, "");
 
@@ -128,9 +74,10 @@ void clusterinfo(char *timestr)
 
 	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
-	nroflines = loadbandmap();
+	loadbandmap();
 
     }
+
     if (cluster == FREQWINDOW) {
 	for (f = 0; f < 8; f++)
 	    mvprintw(15 + f, 4, "                           ");
@@ -152,14 +99,12 @@ void clusterinfo(char *timestr)
 
 	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
 
-	inputbuffer[0] = '\0';
-	strncat(inputbuffer, backgrnd_str, 78);
+	g_strlcpy(inputbuffer, backgrnd_str, 79);
 
 	for (j = 15; j <= 22; j++) {
 	    mvprintw(j, 1, "%s", inputbuffer);
 	}
 
-	inputbuffer[0] = '\0';
 
 	/** \todo minimize lock time */
 	pthread_mutex_lock (&spot_ptr_mutex);
@@ -178,14 +123,6 @@ void clusterinfo(char *timestr)
 	if (k < 0)
 	    k = -1;
 
-	attron(COLOR_PAIR(C_WINDOW) | A_STANDOUT);
-
-	inputbuffer[0] = '\0';
-	strncat(inputbuffer, backgrnd_str, 78);
-
-	for (j = 15; j <= 22; j++) {
-	    mvprintw(j, 1, "%s", inputbuffer);
-	}
 
 	for (j = 15; j <= 22; j++) {
 
@@ -193,27 +130,18 @@ void clusterinfo(char *timestr)
 		if (k > MAX_SPOTS - 1)
 		    k = MAX_SPOTS - 1;
 
+		inputbuffer[0] = '\0';
+
 		if (spotarray[k] >= 0 && spotarray[k] < MAX_SPOTS)
-		    strcpy(inputbuffer, spot_ptr[spotarray[k]]);
+		    g_strlcpy(inputbuffer, spot_ptr[spotarray[k]], 79);
 		else {
 		    mvprintw(24, 0, "error in packet table");
 		}
 
 		if (strlen(inputbuffer) > 14) {
-		    strncat(inputbuffer, backgrnd_str, 65);
-		    inputbuffer[78] = '\0';
-		    mvprintw(j, 1, "%s", inputbuffer);
-		} else {
-		    inputbuffer[0] = '\0';
-		    strncat(inputbuffer, backgrnd_str, 79);
-		    inputbuffer[78] = '\0';
 		    mvprintw(j, 1, "%s", inputbuffer);
 		}
-
-		inputbuffer[0] = '\0';
-
 	    }
-
 	}
 
 	pthread_mutex_unlock (&spot_ptr_mutex);
@@ -221,9 +149,7 @@ void clusterinfo(char *timestr)
 	nicebox(14, 0, 8, 78, "Cluster");
 	refreshp();
     }
-
     printcall();
-
 }
 
 
@@ -236,23 +162,19 @@ int loadbandmap(void)
     extern int cluster;
     extern char *bandmap[MAX_SPOTS];
     extern struct tm *time_ptr;
-    extern int countries[];
-    extern int call_band[];
     extern int xplanet;
     extern char markerfile[];
     extern char lastmsg[];
     extern char spot_ptr[MAX_SPOTS][82];
-    extern int ptr;
+    extern int nr_of_spots;
 
 
-    int i = 0, j, jj, k, m, x, y;
+    int i = 0, j, m, x;
+    unsigned int k;
     int spotminutes = 0;
     int sysminutes = 0;
     int timediff = 0;
     int linepos;
-    int worked;
-    int thisband = 10;		/** \todo should it be NBANDS? */
-    int dupe;
     int spot_age[MAX_SPOTS];
     float spot_freq[MAX_SPOTS];
 
@@ -272,11 +194,15 @@ int loadbandmap(void)
     char xplanetmsg[160];
     dxcc_data *dx;
 
+
     for (i = 0; i < MAX_SPOTS; i++) {
 	if (bandmap[i] != NULL) {
 	    g_free(bandmap[i]);
 	    bandmap[i] = NULL;
 	}
+
+	spot_age[i] = 0;
+	spot_freq[i] = 0.;
     }
 
     j = 0;
@@ -292,13 +218,12 @@ int loadbandmap(void)
 
     pthread_mutex_lock (&spot_ptr_mutex);
 
-    for (j = 0; j < ptr; j++) {
+    for (j = 0; j < nr_of_spots; j++) {
 
 	strncpy ( thisline, spot_ptr[j], 82);
 	if (strncmp(thisline, "DX de ", 6) == 0) {
 
-	    strncpy(spotcall, thisline + 26, 5);
-	    spotcall[5] = '\0';
+	    g_strlcpy(spotcall, thisline + 26, 6);
 
 	    strncpy(spottime, thisline + 70, 4);	// how old?
 	    spottime[4] = spottime[3];
@@ -315,9 +240,8 @@ int loadbandmap(void)
 
 		/* look for duplicates already in bandmap
 		 * => kill older one and keep younger entry */
-		for (k = 0; k <= i - 1; k++) {
-		    callcopy[0] = '\0';
-		    strncat(callcopy, bandmap[k] + 26, 5);
+		for (k = 0; k < i; k++) {
+		    g_strlcpy(callcopy, bandmap[k] + 26, 6);
 
 		    if (strncmp(callcopy, spotcall, 4) == 0) {
 			bandmap[k][0] = 'd';
@@ -338,8 +262,6 @@ int loadbandmap(void)
 
     linepos = (i < 8 ? 0 : i - 8);
 
-    jj = 0;
-
     /* prune markerfile by opening it for write */
     if (xplanet > 0 && nofile == 0) {
 	if ((fp = fopen(markerfile, "w")) == NULL) {
@@ -353,10 +275,8 @@ int loadbandmap(void)
     for (j = linepos; j < linepos + 8; j++) {
 
 	if (bandmap[j] != NULL) {
-	    strncpy(spotline, bandmap[j] + 17, 22);	// freq and call
-	    spotline[22] = '\0';
-	    strncpy(spottime, bandmap[j] + 70, 5);	// time
-	    spottime[5] = '\0';
+	    g_strlcpy(spotline, bandmap[j] + 17, 23);	// freq and call
+	    g_strlcpy(spottime, bandmap[j] + 70, 6);	// time
 	    strcat(spotline, spottime);
 
 	    strncpy(callcopy, bandmap[j] + 26, 16);	// call
@@ -369,28 +289,6 @@ int loadbandmap(void)
 
 	    x = getctynr(callcopy);		// CTY of station
 
-	    y = searchcallarray(callcopy);	// lookup index of call in
-	    					// callarray (if already worked)
-
-	    worked = 0;
-	    dupe = 1;
-
-	    thisband = bandinx;
-
-	    /* check if country was already worked on this band */
-	    if ((countries[x] & inxes[thisband]) != 0)
-		worked = 1;	/* no new country/multi */
-
-	    /* check if already worked on these band */
-	    if (y != -1) {	/*  found */
-		if ((call_band[y] & inxes[thisband]) == 0)
-		    dupe = 0;	/* not worked on this band yet */
-	    }
-
-	    if (inxes[thisband] == 0) {	/* WARC band */
-		worked = 1;		/* show as not needed */
-		dupe = 0;		/* station new, but no country/multi */
-	    }
 
 	    if (x != 0 && xplanet > 0 && nofile == 0) {
 
@@ -447,9 +345,10 @@ int loadbandmap(void)
 		    if (*color != '\0') {
 			sprintf(marker_out, "%4d   %4d   \"%s\"   color=%s\n",
 			    lat, lon, callcopy, color);
+
+			fputs(marker_out, fp);
 		    }
 
-		    fputs(marker_out, fp);
 
 		    fclose(fp);
 		}
@@ -461,8 +360,7 @@ int loadbandmap(void)
     /* append last dx cluster message to markerfile; will be shown at bottom */
     if (xplanet == 1 && nofile == 0) {
 
-	xplanetmsg[0] = '\0';
-	strcat(xplanetmsg, " -82 -120 ");
+	strcpy(xplanetmsg, " -82 -120 ");
 	strcat(xplanetmsg, "\"");
 	strcat(xplanetmsg, lastmsg);
 
@@ -487,8 +385,7 @@ int loadbandmap(void)
 
     refreshp();
 
-    return (i);
-    //--------------------------- the end  ------------------
+    return (i);			/* nr of found spot lines */
 }
 
 
@@ -497,8 +394,7 @@ int getclusterinfo(void)
 {
 
     extern char spot_ptr[MAX_SPOTS][82];
-    extern int ptr;
-    extern int spotarray[];
+    extern int nr_of_spots;
     extern int announcefilter;
     extern int cluster;
     extern char call[];
@@ -552,7 +448,7 @@ int getclusterinfo(void)
 	} else
 	    i++;
 
-	if (i > (ptr - 1))
+	if (i > (nr_of_spots - 1))
 	    break;
 
     }
