@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2014           Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,11 +18,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include<stdlib.h>
-#include<string.h>
-#include "tlf.h"
-#include "clear_display.h"
-
+#ifndef DISPLAYIT_H
+#define DISPLAYIT_H
 
 void displayit(void);
 
+#endif /* end of include guard: DISPLAYIT_H */
