@@ -16,8 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include <time.h>
+#ifndef GET_TIME_H
+#define GET_TIME_H
 
 void get_time(void);
 
+#endif /* GET_TIME_H */
