@@ -25,17 +25,38 @@
 	 *--------------------------------------------------------------*/
 
 #include "getexchange.h"
+#include "tlf.h"
+#include "time_update.h"
 #include "recall_exchange.h"
 #include "addspot.h"
 #include "logit.h"
 #include "cw_utils.h"
 #include <glib.h>
+#include "qtcwin.h"
 #include "locator2longlat.h"
 #include "score.h"
+#include "searchlog.h"
+#include "clear_display.h"
+#include "stoptx.h"
+#include "displayit.h"
+#include "speedupndown.h"
+#include "sendbuf.h"
+#include "scroll_log.h"
+#include "addcall.h"
+#include "makelogline.h"
+#include "store_qso.h"
+#include "qsonr_to_str.h"
+#include "writeparas.h"
+#include "lancode.h"
+#include "keyer.h"
+#include "rtty.h"
+#include "ui_utils.h"
+#include "qtcvars.h"
 
 #define MULTS_POSSIBLE(n) ((char *)g_ptr_array_index(mults_possible, n))
 #define LEN(array) (sizeof(array) / sizeof(array[0]))
 
+
 int play_file(char *audiofile);
 
 
@@ -55,7 +76,6 @@ int getexchange(void)
     extern char message[][80];
     extern char ph_message[14][80];
     extern char hiscall[];
-    extern char buffer[];
     extern char qsonrstr[];
     extern int cqww;
     extern int wpx;
@@ -89,12 +109,14 @@ int getexchange(void)
     extern int commentfield;
     extern int no_rst;
     extern int serial_or_section;
+    extern int ve_cty;
+    extern int w_cty;
 
     int i;
     int x = 0;
     char instring[2];
     char commentbuf[40] = "";
-    int retval;
+    int retval = 0;
     char *gridmult = "";
 
     instring[1] = '\0';
@@ -140,7 +162,7 @@ int getexchange(void)
 	refresh_comment();
 
        	/* wait for next char pressed, but update time, cluster and TRX qrg */
-	nodelay(stdscr, TRUE);  /* main loop waiting for input */
+	/* main loop waiting for input */
 	x = -1;
 	while (x < 1) {
 
@@ -156,13 +178,30 @@ int getexchange(void)
             /* make sure that the wrefresh() inside getch() shows the cursor
              * in the input field */
 	    wmove(stdscr, 12, 54 + strlen(comment));
-	    x = onechar();
+	    x = key_poll();
         }
-        nodelay(stdscr, FALSE);
-
 
 	switch (x) {
 
+	case 17:	// CTRL-Q
+	    {
+		if (qtcdirection == 1 || qtcdirection == 3) {	// in case of QTC=RECV or QTC=BOTH
+		    qtc_main_panel(RECV);
+		}
+		if (qtcdirection == 2) {			// in case of QTC=SEND
+		    qtc_main_panel(SEND);
+		}
+		x=155;
+		continue;
+	    }
+	case 19:	// CTRL+s
+	    {
+		if (qtcdirection == 2 || qtcdirection == 3) {	// in case of QTC=SEND ot QTC=BOTH
+		    qtc_main_panel(SEND);
+		}
+		x=155;
+		continue;
+	    }
 	case 1:						/* ctrl-a */
 	    {
 		addspot();
@@ -224,8 +263,7 @@ int getexchange(void)
 	case 129:
 	    {
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
-		    strcat(buffer, call);	/* F1 */
-		    sendbuf();
+		    sendmessage(call);		/* F1 */
 		} else
 		    play_file(ph_message[5]);	// call
 
@@ -236,7 +274,6 @@ int getexchange(void)
 	    {
 		if (trxmode == CWMODE || trxmode == DIGIMODE) {
 		    sendmessage(message[x - 129]);	/* F2..F10 */
-
 		} else
 		    play_file(ph_message[x - 129]);
 
@@ -454,9 +491,25 @@ int getexchange(void)
 		}
 		refreshp();
 		break;
+	    } else if (cqww == 1 && trxmode == DIGIMODE && ((countrynr == w_cty) || (countrynr == ve_cty))) {
+		if (strlen(comment) < 5) {
+		    mvprintw(13, 54, "state/prov?");
+		    mvprintw(12, 54, comment);
+		    if (x == '\n' || x == 92) {
+			x = 0;
+		    }
+		    else {
+		        refreshp();
+			break;
+		    }
+		    x = 0;
+		}
+		else {
+		    refreshp();
+		    break;
+		}
 	    } else
 		break;
-
 	}
 
     }
@@ -1085,7 +1138,7 @@ void exchange_edit (void)
 	mvprintw(12, 54, comment);
 	mvprintw(12, 54 + b, "");
 
-	i = onechar();
+	i = key_get();
 
 	if (i == 1) {		// ctrl-A, Home
 
