@@ -16,15 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <curses.h>
-#include <time.h>
-#include "get_time.h"
-#include "printcall.h"
-#include "tlf.h"
-
+#ifndef GETWWV_H
+#define GETWWV_H
 
 int getwwv(void);
 
+#endif /* GETWWV_H */
