@@ -20,12 +20,9 @@ extern int multscore[NBANDS];		// number of multipliers worked per
 					// index was 0...5 for only
 					// the non-warc bands!
 
-extern char callarray[MAX_CALLS][20];	// list of all calls worked so far
-extern int callarray_nr;		// number of entries in callarray[]
-extern int call_band[MAX_CALLS];	// for each of them, a bitfield
-					// indicating bands
-extern int call_country[MAX_CALLS];	// for each call, the country
-extern char call_exchange[MAX_CALLS][12]; // for each call, the last exchange
+extern int nr_worked;			// number of worked station
+					// entries in worked[]
+extern struct worked_t worked[MAX_CALLS]; // worked stations
 
 extern int countries[MAX_DATALINES];	// for every country, a bitfield
 					// indicating bands on which it has
@@ -43,9 +40,8 @@ extern int other_flg;
 extern char hiscall[20];
 extern int total;
 extern int band_score[NBANDS];
-extern int zones[41];
+extern int zones[MAX_ZONES];
 extern int wpx;
-extern char prefixes_worked[MAX_CALLS][6];
 extern int arrlss;
 extern int serial_section_mult;
 extern int serial_grid4_mult;
@@ -54,7 +50,6 @@ extern int dx_arrlsections;
 extern int wysiwyg_multi;
 extern int wysiwyg_once;
 extern char pxstr[];
-extern int nr_of_px;
 extern int zonescore[6];
 extern int countryscore[6];
 extern int qsonum;
@@ -62,15 +57,11 @@ extern int countrynr;
 extern int w_cty;
 extern int ve_cty;
 extern int pfxmult;
+extern int pfxmultab;
 extern int minute_timer;
 extern int stewperry_flg;
 extern char myqra[7];
 
-// extern char logline0[81];
-// extern char logline1[81];
-// extern char logline2[81];
-// extern char logline3[81];
-// extern char logline4[];
 extern char logline_edit[5][LOGLINELEN+1];
 #define logline0 logline_edit[0]
 #define logline1 logline_edit[1]
@@ -123,6 +114,5 @@ extern int one_point;
 extern int two_point;
 extern int three_point;
 extern int dxped;
-extern char pointstring[];
 extern int addzone;
 
