@@ -20,6 +20,14 @@
 #include "grabspot.h"
 #include "bandmap.h"
 #include <glib.h>
+#include "fldigixmlrpc.h"
+#include "tlf.h"
+#include "getctydata.h"
+#include "showinfo.h"
+#include "searchlog.h"
+#ifdef HAVE_LIBHAMLIB
+#include <hamlib/rig.h>
+#endif
 
 void send_bandswitch(int outfreq);
 
@@ -51,6 +59,7 @@ void grabspot(void)
 	if (data != NULL) {
 
 	    outfreq = data -> freq;
+	    outfreq -= fldigi_get_carrier();
 	    send_bandswitch( outfreq );
 
 	    strcpy( hiscall, data->call );
@@ -109,6 +118,7 @@ void grab_next(void)
     if (data != NULL) {
 
 	outfreq = data -> freq;
+	outfreq -= fldigi_get_carrier();
 	send_bandswitch( outfreq );
 
 	strcpy( hiscall, data->call );
