@@ -23,29 +23,46 @@
     CW keyboard routine
 
 ------------------------------------------------------------------------*/
-#include "keyer.h"
+#include "tlf.h"
+#include <panel.h>
+#include "clear_display.h"
+#include "ui_utils.h"
+#include "stoptx.h"
+#include "displayit.h"
+#include "speedupndown.h"
+#include "sendbuf.h"
 #include "netkeyer.h"
+#include "nicebox.h"
 
-int mfj1278_control(int x);
+/* size and position of keyer window */
+#define KEYER_LINE_WIDTH 60
+#define KEYER_WIN_WIDTH (KEYER_LINE_WIDTH+2)
+#define KEYER_WIN_HEIGHT 3
+#define KEYER_X (80-KEYER_WIN_WIDTH)/2
+#define KEYER_Y 7
+
+
+void mfj1278_control(int x);
 
 int keyer(void)
 {
 
     extern int cqmode;
     extern char mode[20];
-    extern int bufloc;
-    extern char buffer[];
-    extern char termbuf[];
     extern char message[][80];
     extern char wkeyerbuffer[];
     extern int data_ready;
     extern int keyerport;
     extern int weight;
 
+    WINDOW *win = NULL;
+    PANEL *panel = NULL;
+
     int x = 0, j = 0;
     int cury, curx;
     char nkbuffer[2];
-    char keyerstring[30] = "                              ";
+    char keyerstring[KEYER_LINE_WIDTH+1] = "";
+    int keyerstringpos = 0;
     char weightbuf[15];
     const char txcontrolstring[2] = { 20, '\0' };	// ^t
     const char rxcontrolstring[2] = { 18, '\0' };	// ^r
@@ -53,24 +70,44 @@ int keyer(void)
     const char ctl_c_controlstring[2] = { 92, '\0' };	// '\'
 
     if (keyerport == NO_KEYER)	/* no keyer present */
-	return (1);
+	return 1;
 
     strcpy(mode, "Keyboard");
     clear_display();
     attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
+    if (panel == NULL) {
+	win = newwin(KEYER_WIN_HEIGHT, KEYER_WIN_WIDTH, KEYER_Y, KEYER_Y );
+	if (win == NULL)
+	    return 1;
+	panel = new_panel(win);
+	if (panel == NULL) {
+	    delwin(win);
+	    return 1;
+	}
+    }
+
+    show_panel(panel);
+    werase(win);
+    wnicebox(win, 0, 0, 1, KEYER_LINE_WIDTH, "CW Keyer");
+
     if (keyerport == MFJ1278_KEYER) {
-	buffer[0] = 20;		// send ctrl-t
-	buffer[1] = '\0';
-	if (data_ready != 1) {
-	    strcat(wkeyerbuffer, buffer);
+	if (data_ready != 1) { 		/* switch to tx */
+	    strcat(wkeyerbuffer, txcontrolstring);
 	    data_ready = 1;
 	}
-	buffer[0] = '\0';
     }
 
     while (1) {
-	x = onechar();
+	wattron(win, COLOR_PAIR(C_LOG) | A_STANDOUT);
+	wmove (win, 1, 1);
+	for (j = 0; j < KEYER_LINE_WIDTH; j++) {
+	    waddch (win, ' ');
+	}
+	mvwprintw(win, 1, 1, "%s", keyerstring);
+	refreshp();
+
+	x = key_get();
 
 	if (x == 34) {		/* skip " */
 	    x = 32;
@@ -81,148 +118,71 @@ int keyer(void)
 
 	if (x == 27 || x == 11 || x == 235) {	//      esc, ctrl-k,  alt-k
 	    if (keyerport == MFJ1278_KEYER) {
-		buffer[0] = 18;	// send ctrl-r
-		buffer[1] = '\0';
-		if (data_ready != 1) {
-		    strcat(wkeyerbuffer, buffer);
+		if (data_ready != 1) { 	/* switch back to rx */
+		    strcat(wkeyerbuffer, rxcontrolstring);
 		    data_ready = 1;
 		}
 	    } else {
 		stoptx();
 	    }
 
-	    buffer[0] = '\0';
 	    break;
 	}
 
-
-	if (x == 127 && (strlen(buffer) >= 1)) {	/* erase  */
-
-	    getyx(stdscr, cury, curx);
-	    mvprintw(5, curx - 1, " ");
-	    mvprintw(5, curx - 1, "");
-	    buffer[strlen(buffer) - 1] = '\0';
-	    bufloc--;
-	}
-
 	if (x > 96 && x < 123)	/* upper case only */
 	    x = x - 32;
 
-	if (x > 9 && x < 91) {
-
-	    if (bufloc >= 38)	// maximum buffer = 39
-	    {
-		bufloc = 38;
-		printw("\nBuffer overflow !, bufloc = %d\n", bufloc);
-		refreshp();
-	    } else {
-		if (x > 31 || x == 10) {
-		    if (keyerport == MFJ1278_KEYER) {
-			mfj1278_control(x);
-		    } else if (keyerport == NET_KEYER) {
-			nkbuffer[0] = x;	// 1 char at the time !
-			nkbuffer[1] = '\0';
-			netkeyer(K_MESSAGE, nkbuffer);
-			nkbuffer[0] = '\0';
-// TODO test if that is correct
-			for (j = 0; j < 29; j++) {
-			    keyerstring[j] = keyerstring[j + 1];
-			}
-			keyerstring[28] = x;
-			keyerstring[29] = '\0';
-
-			attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
-			mvprintw(5, 0, "%s", keyerstring);
-			refreshp();
-
-		    }
-		} else		// control char...
-		{
-
-		    if (data_ready != 1) {
-			strcat(wkeyerbuffer, buffer);
-			data_ready = 1;
-		    } else
-			buffer[0] = '\0';
-
-		    getyx(stdscr, cury, curx);
-		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
-		    mvaddstr(0, 0, "  ");
-		    attron(COLOR_PAIR(C_LOG));
-		    mvaddstr(cury, curx, "");
-		    refreshp();
-
-		    strcat(termbuf, buffer);
-		    strcat(termbuf, " ");
-		    mvprintw(5, 0, termbuf);
-		    refreshp();
-
-		    if ((strlen(buffer) + strlen(termbuf) > 39)
-			|| x == '=') {
-			mvprintw(5, 0, "                         ");
-			mvprintw(5, 0, "");
-			refreshp();
-			displayit();
-		    }
-
-		    bufloc = 0;
-		    buffer[bufloc] = '\0';
+	if (x > 9 && x < 91) { 	/* drop all other control char... */
+	    if (x > 31 || x == 10) {
+		if (keyerport == MFJ1278_KEYER) {
+		    mfj1278_control(x);
+		} else if (keyerport == NET_KEYER) {
+		    nkbuffer[0] = x;	// 1 char at the time !
+		    nkbuffer[1] = '\0';
+		    netkeyer(K_MESSAGE, nkbuffer);
 		}
+
+		/* if display field is full move text one left */
+		if (keyerstringpos == KEYER_LINE_WIDTH - 1) {
+		    for (j = 0; j < KEYER_LINE_WIDTH - 1; j++) {
+		    	keyerstring[j] = keyerstring[j + 1];
+		    }
+		    keyerstringpos--;
+		}
+		/* add new character for display */
+		keyerstring[keyerstringpos++] = x;
+		keyerstring[keyerstringpos] = '\0';
 	    }
 	} else {
 
 	    switch (x) {
-	    case 9:
-	    case 32:
-		{
-		    bufloc = 0;
-		    buffer[bufloc] = '\0';
-		    strcpy(mode, "Log     ");
-		    clear_display();
-		    return (2);
-		}
 	    case '\n':
 	    case 13:
 		{
-		    if (keyerport == MFJ1278_KEYER && strlen(buffer) < 39) {
-			strcat(buffer, crcontrolstring);
-			sendbuf();
-			bufloc = 0;
+		    if (keyerport == MFJ1278_KEYER) {
+			sendmessage(crcontrolstring);
 		    }
 		    break;
 		}
 
-	    case 27:
-	    case 11:
-		{
-		    stoptx();
-		    bufloc = 0;
-		    buffer[bufloc] = '\0';
-		    strcpy(mode, "Log     ");
-		    clear_display();
-		    return (2);
-		}
 	    case 123:		/* { */
 		{
 		    if (keyerport == MFJ1278_KEYER) {
-			strcat(buffer, txcontrolstring);
-			sendbuf();
+			sendmessage(txcontrolstring);
 		    }
 		    break;
 		}
 	    case 125:		/* } */
 		{
 		    if (keyerport == MFJ1278_KEYER) {
-			strcat(buffer, rxcontrolstring);
-			sendbuf();
+			sendmessage(rxcontrolstring);
 		    }
 		    break;
 		}
 	    case 92:		/* \ */
 		{
 		    if (keyerport == MFJ1278_KEYER) {
-			strcat(buffer, ctl_c_controlstring);
-			sendbuf();
+			sendmessage(ctl_c_controlstring);
 		    }
 		    break;
 		}
@@ -325,6 +285,7 @@ int keyer(void)
 
 	}
     }
+    hide_panel(panel);
 
     if (cqmode == CQ)
         strcpy(mode, "Log     ");
@@ -333,19 +294,17 @@ int keyer(void)
 
     clear_display();
 
-    return (2);			/* show end of keyer  routine */
+    return 0;			/* show end of keyer  routine */
 }
 
-/*  ------------------------------------------  convert input for 1278 ctrl -----------------------*/
+/* ----------------  convert input for 1278 ctrl -----------------------*/
 
-int mfj1278_control(int x)
+void mfj1278_control(int x)
 {
-
     extern int trxmode;
     extern char wkeyerbuffer[];
     extern int data_ready;
 
-    int y = 0;
     char buffer[2];
 
     if (trxmode == CWMODE || trxmode == DIGIMODE) {
@@ -361,10 +320,5 @@ int mfj1278_control(int x)
 	    data_ready = 1;
 	}
 	buffer[0] = '\0';
-
     }
-
-    y = x;
-
-    return (y);
 }
