@@ -18,8 +18,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "tlf.h"
 #include "lancode.h"
+#include "tlf.h"
+#include <fcntl.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <netdb.h>
+#include <syslog.h>
 
 int lan_socket_descriptor;
 struct sockaddr_in lan_sin;
@@ -265,13 +271,12 @@ int lan_send(char *lanbuffer)
 
 int send_lan_message(int opcode, char *message)
 {
-
-    char sendbuffer[84];
+    char sendbuffer[102];
 
     sendbuffer[0] = thisnode;
     sendbuffer[1] = opcode;
     sendbuffer[2] = '\0';
-    strncat(sendbuffer, message, 80);
+    strncat(sendbuffer, message, 98);
     if (opcode == CLUSTERMSG) {
 	if (cl_send_inhibit == 0) {
 	    strcat(sendbuffer, "\n");
@@ -305,6 +310,20 @@ int send_lan_message(int opcode, char *message)
 	sendbuffer[14] = '\0';
 	lan_send(sendbuffer);
     }
+    if (opcode == QTCRENTRY) {
+	strcat(sendbuffer, "\n");
+	sendbuffer[94] = '\0';
+	lan_send(sendbuffer);
+    }
+    if (opcode == QTCSENTRY) {
+	strcat(sendbuffer, "\n");
+	sendbuffer[100] = '\0';
+	lan_send(sendbuffer);
+    }
+    if (opcode == QTCFLAG) {
+	strcat(sendbuffer, "\n");
+	lan_send(sendbuffer);
+    }
 
     return (0);
 }
