@@ -16,19 +16,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <fcntl.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#include <syslog.h>
-#include <curses.h>
-#include <time.h>
+#ifndef LANCODE_H
+#define LANCODE_H
 
 #define MAXNODES 8
 
@@ -39,6 +28,9 @@
 #define FREQMSG 53
 #define INCQSONUM 54
 #define TIMESYNC 55
+#define QTCRENTRY 56
+#define QTCSENTRY 57
+#define QTCFLAG 58
 
 int lanrecv_init(void);
 int lan_recv_close(void);
@@ -50,3 +42,5 @@ int send_lan_message(int opcode , char *message);
 int talk(void);
 int send_freq(float freq);
 int send_time(void) ;
+
+#endif /* LANCODE_H */
