@@ -16,13 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <time.h>
-#include <stdio.h>
-#include<stdlib.h>
-#include<string.h>
-#include<unistd.h>
-#include "get_time.h"
-#include "tlf.h"
+#ifndef LAST10_H
+#define LAST10_H
 
 int last10(void);
 
+#endif /* LAST10_H */
