@@ -2,6 +2,7 @@
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
  *               2013           Thomas Beierlein <tb@forth-ev.de>
+ *               2013           Ervin Hegedüs - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +26,22 @@
 
 #include "globalvars.h"
 #include "log_to_disk.h"
+#include <pthread.h>
+#include "tlf.h"
+#include "scroll_log.h"
+#include "addcall.h"
+#include "makelogline.h"
+#include "store_qso.h"
+#include "qsonr_to_str.h"
+#include "writeparas.h"
+#ifdef HAVE_LIBHAMLIB
+#include <hamlib/rig.h>
+#endif
+#include "gettxinfo.h"
+#include "lancode.h"
+#include "addspot.h"
 #include "score.h"
+#include "ui_utils.h"
 
 pthread_mutex_t disk_mutex = PTHREAD_MUTEX_INITIALIZER;
 
@@ -37,11 +53,11 @@ pthread_mutex_t disk_mutex = PTHREAD_MUTEX_INITIALIZER;
  */
 int log_to_disk(int from_lan)
 {
-    extern int use_rxvt;
     extern char hiscall[];
     extern char comment[];
     extern char my_rst[];
     extern char his_rst[];
+    extern char last_rst[4];
     extern char qsonrstr[5];
     extern char lan_logline[];
     extern int rit;
@@ -79,6 +95,7 @@ int log_to_disk(int from_lan)
 	hiscall[0] = '\0';	/* reset the call  string */
 	comment[0] = '\0';	/* reset the comment  string */
 
+	strncpy(last_rst, his_rst, sizeof(last_rst)); /* remember last report */
 	his_rst[1] = '9';	/* restore RST to 599 */
 	my_rst[1] = '9';
 
@@ -112,10 +129,7 @@ int log_to_disk(int from_lan)
 
     lan_mutex = 0;
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);	/* erase comment  field */
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));	/* erase comment  field */
 
     if (!from_lan)
 	mvprintw(12, 54, "                          ");
