@@ -1,7 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@amsat.org>
- * 		 2010, 2011 Thomas Beierlein <tb@forth-ev.de>
+ * 		 2010-2014 Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,21 @@
  ------------------------------------------------------------------------*/
 
 #include "logit.h"
+#include "tlf.h"
+#include "clear_display.h"
+#include "printcall.h"
+#include "callinput.h"
+#include "getexchange.h"
+#include "sendbuf.h"
+#include "sendspcall.h"
+#include "log_to_disk.h"
+#include "keyer.h"
+#include "recall_exchange.h"
+#include "sendqrg.h"
+#include "lancode.h"
+#include "set_tone.h"
+#include "searchlog.h"
+#include "ui_utils.h"
 
 void refresh_comment(void);
 
@@ -34,7 +49,6 @@ void *logit(void *ptr)
     extern char hiscall[];
     extern int cqmode;
     extern int contest;
-    extern char buffer[];
     extern char message[][80];
     extern char ph_message[14][80];
     extern char comment[];
@@ -96,7 +110,7 @@ void *logit(void *ptr)
 		if ((cqmode == CQ) && (contest == CONTEST)
 			&& (defer_store == 0)) {	/* CQ mode */
 		    if (trxmode == CWMODE || trxmode == DIGIMODE)
-			strcpy(buffer, message[2]);	/*  send F3  on  ENTER  */
+			sendmessage(message[2]);    /*  send F3  on  ENTER  */
 		    else {
 			play_file(ph_message[2]);
 			if (exchange_serial == 1)
@@ -133,7 +147,6 @@ void *logit(void *ptr)
 			}
 		    }
 
-		    sendbuf();
 		    defer_store = 1;
 		    callreturn = 0;
 		}
@@ -142,7 +155,7 @@ void *logit(void *ptr)
 			&& (defer_store == 0)) {	/* S&P mode */
 
 		    if (cqww == 1) {
-			if (recall_exchange() == -1)
+			if (strlen(comment) == 0 && recall_exchange() == -1)
 			    strcpy(comment, cqzone);	/* fill in the zone */
 
 			refresh_comment();
@@ -179,7 +192,7 @@ void *logit(void *ptr)
 			    if (simulator != 0)
 				write_tone();
 			} else {
-			    play_file(ph_message[13]);
+			    play_file(ph_message[CQ_TU_MSG]);
 			}
 
 			defer_store = 0;
@@ -190,7 +203,7 @@ void *logit(void *ptr)
 			if (trxmode == CWMODE || trxmode == DIGIMODE) {
 			    sendmessage(sp_return); /* send S&P return */
 			} else
-			    play_file(ph_message[12]);
+			    play_file(ph_message[SP_TU_MSG]);
 
 			defer_store = 0;
 		    }
@@ -208,7 +221,7 @@ void *logit(void *ptr)
 		HideSearchPanel();
 	    }
 
-	    if (callreturn == 11 || callreturn == 44 || callreturn == 235) {	/*  CTRL K  */
+	    if (callreturn == 11 || callreturn == 44) {	/*  CTRL K  */
 		getyx(stdscr, cury, curx);
 		mvprintw(5, 0, "");
 		keyer();
@@ -226,12 +239,8 @@ void *logit(void *ptr)
 /** reprint comment field */
 void refresh_comment(void) {
     extern char comment[];
-    extern int use_rxvt;
 
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(NORMCOLOR) | A_BOLD);
-    else
-	attron(COLOR_PAIR(NORMCOLOR));
+    attron(modify_attr(COLOR_PAIR(NORMCOLOR)));
 
     mvprintw(12, 54, "                          ");
     mvprintw(12, 54, comment);
