@@ -226,6 +226,8 @@ void prepare_fixed_part(void) {
  *     class - TX count + operator class, sctn - ARRL/RAC section
  */
 void prepare_specific_part(void) {
+    extern int pfxnummultinr;
+    extern int excl_add_veto;
     int new_pfx;
     int sr_nr = 0;
     char grid[7] = "";
@@ -268,6 +270,12 @@ void prepare_specific_part(void) {
 	} else
 		strcat (logline4, zone_export);
 */
+	if (trxmode == DIGIMODE && cqww == 1 && strlen(comment) < 5) {
+	    comment[2] = ' ';
+	    comment[3] = 'D';
+	    comment[4] = 'X';
+	    comment[5] = '\0';
+	}
 	strncat(logline4, comment, 22);
     } else {	//----------------------end cqww ---------------
 	strncat(logline4, comment, 22);
@@ -280,9 +288,12 @@ void prepare_specific_part(void) {
 
     /* If WPX
      * -> add prefix to prefixes_worked and include new pfx in log line */
-    new_pfx = (add_pfx(pxstr) == 0);	/* add prefix, remember if new */
+    new_pfx = 0;
+    if (! (pfxmultab == 1 && excl_add_veto == 1)) {
+	new_pfx = (add_pfx(pxstr) == 0);	/* add prefix, remember if new */
+    }
 
-    if (wpx ==1) {			/* wpx */
+    if (wpx ==1 || pfxmultab == 1) {			/* wpx */
 	if (new_pfx) {
 	    /** \todo FIXME: prefix can be longer than 5 char, e.g. LY1000 */
 	    strncat(logline4, pxstr, 5);
@@ -377,7 +388,7 @@ void prepare_specific_part(void) {
 
 	fillto(77);
 
-    } else if (pacc_pa_flg == 1) {
+    } else if (pacc_pa_flg == 1 || pfxnummultinr > 0) {
 
 	logline4[68] = '\0';
 
