@@ -22,6 +22,13 @@
 	 *--------------------------------------------------------------*/
 
 #include "messagechange.h"
+#include "tlf.h"
+#include "clear_display.h"
+#include "nicebox.h"
+#include "ui_utils.h"
+#include "writeparas.h"
+
+
 
 int message_change(int x)
 {
@@ -48,7 +55,7 @@ int message_change(int x)
     attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
 
     while (1) {
-	bufnr = onechar();
+	bufnr = toupper(key_get());
 
 	if ((bufnr == 'C') || (bufnr == 'S'))
 	    break;
@@ -113,8 +120,8 @@ int message_change(int x)
 
     writeparas();
 
-    strncpy(sp_return, message[12], 79);
-    strncpy(cq_return, message[13], 79);
+    strncpy(sp_return, message[SP_TU_MSG], 79);
+    strncpy(cq_return, message[CQ_TU_MSG], 79);
 
     return (0);
 }
