@@ -19,11 +19,15 @@
  */
 #include "muf.h"
 #include "tlf.h"
+#include "ui_utils.h"
 #include "get_time.h"
 #include "dxcc.h"
+#include "sunup.h"
 #include <panel.h>
+#include <math.h>
+
+#define RADIAN		(180.0 / M_PI)
 
-extern int use_rxvt;
 extern double r;
 extern int m;
 extern struct tm *time_ptr;
@@ -42,7 +46,6 @@ static double power(man, ex)
 double man, ex;
 {
     return exp(ex * log(man));
-
 }
 
 static void interlat()
@@ -140,12 +143,12 @@ static void e_layer()
 
 int muf(void)
 {
-    extern char C_QTH_Lat[];
-    extern char C_QTH_Long[];
-    extern char C_DEST_Lat[];
-    extern char C_DEST_Long[];
-    extern double sunrise;
-    extern double sundown;
+    extern double QTH_Lat;
+    extern double QTH_Long;
+    extern double DEST_Lat;
+    extern double DEST_Long;
+    double sunrise;
+    double sundown;
 
     extern int mycountrynr;
     extern int countrynr;
@@ -156,7 +159,6 @@ int muf(void)
     static double la, l, mf, lh;
     static long ve, ho;
     static int correct;
-    int key;
     char mycountry[40];
     char country[40];
     int i;
@@ -175,10 +177,10 @@ int muf(void)
     correct = 0;
     n = 0.0;
 
-    xt = atof(C_QTH_Lat);
-    yt = atof(C_QTH_Long);
-    xr = atof(C_DEST_Lat);
-    yr = atof(C_DEST_Long);
+    xt = QTH_Lat;
+    yt = QTH_Long;
+    xr = DEST_Lat;
+    yr = DEST_Long;
 
     get_time();
 //strftime(time_buf, 60, "    %d-%b-%Y %H:%M ",  time_ptr);     ### bug fix
@@ -225,10 +227,7 @@ int muf(void)
     strncpy(country, dx->countryname, 25);
 
     wclear(win);
-    if (use_rxvt == 0)
-	wattron(win, COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
-    else
-	wattron(win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+    wattron(win, modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
     for (i = 0; i < 25; i++)
 	mvwprintw(win, i, 0,
@@ -241,7 +240,8 @@ int muf(void)
     mvwprintw(win, 4, 40, "Azim  :   %3ld degrees.", (long) floor(u + 0.5));
     mvwprintw(win, 5, 40, "F-hops:    %2.0f", n);
 
-    sunup(xr);	/* calculate local sunup and down at destination lattitude */
+    sunup(xr, &sunrise, &sundown);	/* calculate local sunup and down
+    					   at destination lattitude */
 
     /* transform to UTC based on longitude from country description */
     td = (yr * 4) / 60 ; 	/* 4 degree/min */
@@ -324,7 +324,7 @@ int muf(void)
     mvwprintw(win, 23, 0, " --- Press a key to continue --- ");
     refreshp();
 
-    key = getch();
+    (void)key_get();
 
     hide_panel(pan);
     del_panel(pan);
