@@ -16,6 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
+#ifndef MULTIPLIERINFO_H
+#define MULTIPLIERINFO_H
 
 int multiplierinfo(void);
+
+#endif /* MULTIPLIERINFO_H */
