@@ -1,7 +1,7 @@
 /*
 * Tlf - contest logging program for amateur radio operators
 * Copyright (C) 2001-2002-2003-2004 Rein Couperus <pa0rct@amsat.org>
-* 		2011-2014           Thomas Beierlein <tb@forth-ev.de>
+* 		2011-2015           Thomas Beierlein <tb@forth-ev.de>
 * 		2013 		    Fred DH5FS
 *               2013-2014           Ervin Hegedus - HA2OS <airween@gmail.com>
 *
@@ -21,20 +21,23 @@
 */
 #include "parse_logcfg.h"
 #include "tlf.h"
-#include "write_tone.h"
-#include "cw_utils.h"
-#include "speedup.h"
-#include "speeddown.h"
-#include <curses.h>
-#include <string.h>
-#include "startmsg.h"
 #include <glib.h>
+#include "cw_utils.h"
+#include "speedupndown.h"
+#include "startmsg.h"
+#include "bandmap.h"
+#include "locator2longlat.h"
+#include "getpx.h"
+#include "setcontest.h"
+#include "lancode.h"
+#include "getctydata.h"
 #ifdef HAVE_LIBHAMLIB
 #include <hamlib/rig.h>
 #endif
-#include <ctype.h>
 #include "bandmap.h"
 #include "locator2longlat.h"
+#include "dxcc.h"
+#include "qtcvars.h"
 
 extern int keyerport;
 extern char tonestr[];
@@ -48,6 +51,7 @@ extern int shortqsonr;
 extern char * cabrillo;
 
 int exist_in_country_list();
+int continent_found();
 
 char inputbuffer[160];
 FILE *fp;
@@ -56,7 +60,7 @@ void KeywordNotSupported(char *keyword);
 void ParameterNeeded(char *keyword);
 void WrongFormat(char *keyword);
 
-#define  MAX_COMMANDS 162	/* commands in list */
+#define  MAX_COMMANDS 228	/* commands in list */
 
 
 int read_logcfg(void)
@@ -119,6 +123,21 @@ int read_logcfg(void)
     return( status );
 }
 
+/** convert band string into index number (0..NBANDS-1) */
+int getidxbybandstr(char *confband) {
+    static char bands_strings[NBANDS][4] = {"160", "80", "40", "30", "20", "17", "15", "12", "10"};
+    int i;
+
+    g_strchomp(confband);
+
+    for(i=0; i<NBANDS; i++) {
+	if (strcmp(confband, g_strchomp(bands_strings[i])) == 0) {
+	    return i;
+	}
+    }
+    return -1;
+}
+
 
 static int confirmation_needed;
 
@@ -239,12 +258,17 @@ int parse_logcfg(char *inputbuffer)
     extern int dx_cont_points;
     extern int countrylist_points;
     extern int countrylist_only;
+    extern int continentlist_points;
+    extern int continentlist_only;
     char c_temp[11];
     extern int my_cont_points;
     extern int dx_cont_points;
     extern int mult_side;
-    extern char mit_multiplier_list[][6];
-    char *mit_mult_array;
+    extern char countrylist[][6];
+
+    extern char continent_multiplier_list[7][3];
+    extern int exclude_multilist_type;
+
 /* end LZ3NY mods */
     extern int tlfcolors[8][2];
     extern char synclogfile[];
@@ -258,6 +282,11 @@ int parse_logcfg(char *inputbuffer)
     extern int logfrequency;
     extern int ignoredupe;
     extern char myqra[7];
+    extern int bandweight_points[NBANDS];
+    extern int bandweight_multis[NBANDS];
+    extern t_pfxnummulti pfxnummulti[MAXPFXNUMMULT];
+    extern int pfxnummultinr;
+    extern int pfxmultab;
 
     char commands[MAX_COMMANDS][30] = {
 	"enable",		/* 0 */		/* deprecated */
@@ -422,7 +451,73 @@ int parse_logcfg(char *inputbuffer)
 	"NO_RST",
 	"MYQRA",
 	"POWERMULT",		/* 160 */
-	"SERIAL_OR_SECTION"
+	"SERIAL_OR_SECTION",
+	"QTC",
+	"CONTINENTLIST",
+	"CONTINENT_LIST_POINTS",
+	"USE_CONTINENTLIST_ONLY",  /* 165 */
+	"BANDWEIGHT_POINTS",
+	"BANDWEIGHT_MULTIS",
+	"PFX_NUM_MULTIS",
+	"PFX_MULT_MULTIBAND",
+	"QR_F1",		/* 170 */
+	"QR_F2",
+	"QR_F3",
+	"QR_F4",
+	"QR_F5",
+	"QR_F6",		/* 175 */
+	"QR_F7",
+	"QR_F8",
+	"QR_F9",
+	"QR_F10",
+	"QR_F11",		/* 180 */
+	"QR_F12",
+	"QS_F1",
+	"QS_F2",
+	"QS_F3",
+	"QS_F4",
+	"QS_F5",
+	"QS_F6",
+	"QS_F7",
+	"QS_F8",
+	"QS_F9",		/* 190 */
+	"QS_F10",
+	"QS_F11",
+	"QS_F12",
+	"QR_VKM1",
+	"QR_VKM2",
+	"QR_VKM3",
+	"QR_VKM4",
+	"QR_VKM5",
+	"QR_VKM6",
+	"QR_VKM7",			/* 200 */
+	"QR_VKM8",
+	"QR_VKM9",
+	"QR_VKM10",
+	"QR_VKM11",
+	"QR_VKM12",
+	"QR_VKSPM",
+	"QR_VKCQM",
+	"QS_VKM1",
+	"QS_VKM2",
+	"QS_VKM3",			/* 210 */
+	"QS_VKM4",
+	"QS_VKM5",
+	"QS_VKM6",
+	"QS_VKM7",
+	"QS_VKM8",
+	"QS_VKM9",
+	"QS_VKM10",
+	"QS_VKM11",
+	"QS_VKM12",
+	"QS_VKSPM",		/* 220 */
+	"QS_VKCQM",
+	"QTCREC_RECORD",
+	"QTCREC_RECORD_COMMAND",
+	"EXCLUDE_MULTILIST",
+	"S&P_CALL_MSG",
+	"QTC_CAP_CALLS",
+	"QTC_AUTO_FILLTIME"
     };
 
     char **fields;
@@ -467,7 +562,6 @@ int parse_logcfg(char *inputbuffer)
     g_strlcpy( teststring, fields[0], sizeof(teststring) );
 
     for (ii = 0; ii < MAX_COMMANDS; ii++) {
-
 	if (strcmp(teststring, commands[ii]) == 0) {
 	    break;
 	}
@@ -495,17 +589,18 @@ int parse_logcfg(char *inputbuffer)
 	}
     case 14:{
     	    PARAMETER_NEEDED(teststring);
-	    strcpy(message[12], fields[1]);
-	    strcpy(sp_return, message[12]);
+	    strcpy(message[SP_TU_MSG], fields[1]);
+	    strcpy(sp_return, message[SP_TU_MSG]);
 	    break;
 	}
     case 15:{
     	    PARAMETER_NEEDED(teststring);
-	    strcpy(message[13], fields[1]);
-	    strcpy(cq_return, message[13]);
+	    strcpy(message[CQ_TU_MSG], fields[1]);
+	    strcpy(cq_return, message[CQ_TU_MSG]);
 	    break;	/* end messages */
 	}
     case 16:{
+	    char *tmpcall;
     	    PARAMETER_NEEDED(teststring);
 	    if (strlen(fields[1]) > 20) {
 		mvprintw(6,0,
@@ -519,8 +614,11 @@ int parse_logcfg(char *inputbuffer)
 		refreshp();
 		exit(1);
 	    }
-	    /* strip NL and trailing whitespace */
-	    g_strlcpy( call, g_strchomp(fields[1]), 20 );
+
+	    /* strip NL and trailing whitespace, convert to upper case */
+	    tmpcall = g_ascii_strup(g_strchomp(fields[1]), -1);
+	    g_strlcpy( call, tmpcall, 20 );
+	    g_free(tmpcall);
 	    /* as other code parts rely on a trailing NL on the call
 	     * we add back such a NL for now */
 	    strcat( call, "\n");
@@ -654,8 +752,8 @@ int parse_logcfg(char *inputbuffer)
 		    g_strstrip(bm_fields[1]);
 		    livetime = atoi(bm_fields[1]);
 		    if (livetime >= 30)
-			/* aging called every 2 seconds */
-			bm_config.livetime = livetime/2;
+			/* aging called each second */
+			bm_config.livetime = livetime;
 		}
 
 
@@ -1008,33 +1106,34 @@ int parse_logcfg(char *inputbuffer)
 	    nob4 = 1;
 	    break;
 	}
-/* LZ3NY mods */
+
     case 95:{
-	    /* COUNTRY_LIST   (in file or listed in logcfg.dat)     LZ3NY
-	       First of all we are checking if inserted data in
-	       COUNTRY_LIST= is a file name.  If it is we start
-	       parsing the file. If we got our case insensitive contest name,
-	       we copy the multipliers from it into multipliers_list.
-	       If the input was not a file name we directly copy it into
-	       multiplier_list (must not have a preceeding contest name).
-	       The last step is to parse the multipliers_list into an array
-	       (mit_multiplier_list) for future use.
+	    /* COUNTRYLIST   (in file or listed in logcfg.dat)     LZ3NY
 	     */
 
-	    int mit_fg = 0;
-	    static char multiplier_list[50] = ""; 	/* use only first
+	    int counter = 0;
+	    static char country_list_raw[50] = ""; 	/* use only first
 							   COUNTRY_LIST
 							   definition */
-	    char mit_multlist[255] = "";
+	    char temp_buffer[255] = "";
 	    char buffer[255] = "";
 	    FILE *fp;
 
 	    PARAMETER_NEEDED(teststring);
-	    if (strlen(multiplier_list) == 0) {	/* if first definition */
-		g_strlcpy(mit_multlist, fields[1], sizeof(mit_multlist));
-		g_strchomp(mit_multlist);	/* drop trailing whitespace */
+	    if (strlen(country_list_raw) == 0) {/* only if first definition */
 
-		if ((fp = fopen(mit_multlist, "r")) != NULL) {
+	       /* First of all we are checking if the parameter <xxx> in
+	       COUNTRY_LIST=<xxx> is a file name.  If it is we start
+	       parsing the file. If we  find a line starting with our
+	       case insensitive contest name, we copy the countries from
+	       that line into country_list_raw.
+	       If the input was not a file name we directly copy it into
+	       country_list_raw (must not have a preceeding contest name). */
+
+		g_strlcpy(temp_buffer, fields[1], sizeof(temp_buffer));
+		g_strchomp(temp_buffer);	/* drop trailing whitespace */
+
+		if ((fp = fopen(temp_buffer, "r")) != NULL) {
 
 		    while ( fgets(buffer, sizeof(buffer), fp) != NULL ) {
 
@@ -1045,7 +1144,7 @@ int parse_logcfg(char *inputbuffer)
 			if (strncasecmp (buffer, whichcontest,
 				strlen(whichcontest) - 1) == 0) {
 
-			    strncpy(multiplier_list,
+			    strncpy(country_list_raw,
 				    buffer + strlen(whichcontest) + 1,
 				    strlen(buffer) - 1);
 			}
@@ -1054,20 +1153,21 @@ int parse_logcfg(char *inputbuffer)
 		    fclose(fp);
 		} else {	/* not a file */
 
-		    if (strlen(mit_multlist) > 0)
-			strcpy(multiplier_list, mit_multlist);
+		    if (strlen(temp_buffer) > 0)
+			strcpy(country_list_raw, temp_buffer);
 		}
 	    }
 
-	    /* LZ3NY creating the array */
-	    mit_mult_array = strtok(multiplier_list, ":,.- \t");
-	    mit_fg = 0;
+	    /* parse the country_list_raw string into an array
+	     * (countrylist) for future use. */
+	    tk_ptr = strtok(country_list_raw, ":,.- \t");
+	    counter = 0;
 
-	    if (mit_mult_array != NULL) {
-		while (mit_mult_array) {
-		    strcpy(mit_multiplier_list[mit_fg], mit_mult_array);
-		    mit_mult_array = strtok(NULL, ":,.-_\t ");
-		    mit_fg++;
+	    if (tk_ptr != NULL) {
+		while (tk_ptr) {
+		    strcpy(countrylist[counter], tk_ptr);
+		    tk_ptr = strtok(NULL, ":,.-_\t ");
+		    counter++;
 		}
 	    }
 
@@ -1375,6 +1475,310 @@ int parse_logcfg(char *inputbuffer)
 		 break;
 	    }
 
+    case 162:{
+	    PARAMETER_NEEDED(teststring);
+	    if (strncmp(fields[1], "RECV", 4) == 0) {
+	        qtcdirection = RECV;
+	    }
+	    if (strncmp(fields[1], "SEND", 4) == 0) {
+	        qtcdirection = SEND;
+	    }
+	    else if (strcmp(fields[1], "BOTH")) {
+	        qtcdirection = RECV | SEND;
+	    }
+	    if (qtcdirection == 0) {
+		KeywordNotSupported(teststring);
+	    }
+	    else {
+		int q;
+		for(q=0; q<QTC_RY_LINE_NR; q++) {
+		    qtc_ry_lines[q].content[0] = '\0';
+		    qtc_ry_lines[q].attr = 0;
+		}
+	    }
+	    break;
+	}
+
+    case 163:{
+	    /* based on LZ3NY code, by HA2OS
+	       CONTINENT_LIST   (in file or listed in logcfg.dat),
+	       First of all we are checking if inserted data in
+	       CONTINENT_LIST= is a file name.  If it is we start
+	       parsing the file. If we got our case insensitive contest name,
+	       we copy the multipliers from it into multipliers_list.
+	       If the input was not a file name we directly copy it into
+	       cont_multiplier_list (must not have a preceeding contest name).
+	       The last step is to parse the multipliers_list into an array
+	       (continent_multiplier_list) for future use.
+	     */
+
+	    int counter = 0;
+	    static char cont_multiplier_list[50] = ""; 	/* use only first
+							   CONTINENT_LIST
+							   definition */
+	    char temp_buffer[255] = "";
+	    char buffer[255] = "";
+	    FILE *fp;
+
+	    PARAMETER_NEEDED(teststring);
+	    if (strlen(cont_multiplier_list) == 0) {	/* if first definition */
+		g_strlcpy(temp_buffer, fields[1], sizeof(temp_buffer));
+		g_strchomp(temp_buffer);	/* drop trailing whitespace */
+
+		if ((fp = fopen(temp_buffer, "r")) != NULL) {
+
+		    while ( fgets(buffer, sizeof(buffer), fp) != NULL ) {
+
+			g_strchomp( buffer ); /* no trailing whitespace*/
+
+			/* accept only a line starting with the contest name
+			 * (CONTEST=) followed by ':' */
+			if (strncasecmp (buffer, whichcontest,
+				strlen(whichcontest) - 1) == 0) {
+
+			    strncpy(cont_multiplier_list,
+				    buffer + strlen(whichcontest) + 1,
+				    strlen(buffer) - 1);
+			}
+		    }
+
+		    fclose(fp);
+		} else {	/* not a file */
+
+		    if (strlen(temp_buffer) > 0)
+			strcpy(cont_multiplier_list, temp_buffer);
+		}
+	    }
+
+	    /* creating the array */
+	    tk_ptr = strtok(cont_multiplier_list, ":,.- \t");
+	    counter = 0;
+
+	    if (tk_ptr != NULL) {
+		while (tk_ptr) {
+		    strncpy(continent_multiplier_list[counter], tk_ptr, 2);
+		    tk_ptr = strtok(NULL, ":,.-_\t ");
+		    counter++;
+		}
+	    }
+
+	    setcontest();
+	    break;
+	}
+
+
+    case 164:{		// CONTINENT_LIST_POINTS
+	    PARAMETER_NEEDED(teststring);
+	    g_strlcpy(c_temp, fields[1], sizeof(c_temp));
+	    if (continentlist_points == -1) {
+		continentlist_points = atoi(c_temp);
+	    }
+
+	    break;
+	}
+    case 165:{		// CONTINENT_LIST_ONLY
+	    continentlist_only = 1;
+	    break;
+	}
+
+    case 166:{		// BANDWEIGHT_POINTS
+	    PARAMETER_NEEDED(teststring);
+	    static char bwp_params_list[50] = "";
+	    int bandindex = -1;
+
+	    if (strlen(bwp_params_list) == 0) {
+		g_strlcpy(bwp_params_list, fields[1], sizeof(bwp_params_list));
+		g_strchomp(bwp_params_list);
+	    }
+
+	    tk_ptr = strtok(bwp_params_list, ";:,");
+	    if (tk_ptr != NULL) {
+		while (tk_ptr) {
+
+		    bandindex = getidxbybandstr(g_strchomp(tk_ptr));
+		    tk_ptr = strtok(NULL, ";:,");
+		    if (tk_ptr != NULL && bandindex >= 0) {
+			bandweight_points[bandindex] = atoi(tk_ptr);
+		    }
+		    tk_ptr = strtok(NULL, ";:,");
+		}
+	    }
+	    break;
+	}
+
+    case 167:{		// BANDWEIGHT_MULTIS
+	    PARAMETER_NEEDED(teststring);
+	    static char bwm_params_list[50] = "";
+	    int bandindex = -1;
+
+	    if (strlen(bwm_params_list) == 0) {
+		g_strlcpy(bwm_params_list, fields[1], sizeof(bwm_params_list));
+		g_strchomp(bwm_params_list);
+	    }
+
+	    tk_ptr = strtok(bwm_params_list, ";:,");
+	    if (tk_ptr != NULL) {
+		while (tk_ptr) {
+
+		    bandindex = getidxbybandstr(g_strchomp(tk_ptr));
+		    tk_ptr = strtok(NULL, ";:,");
+		    if (tk_ptr != NULL && bandindex >= 0) {
+			bandweight_multis[bandindex] = atoi(tk_ptr);
+		    }
+		    tk_ptr = strtok(NULL, ";:,");
+		}
+	    }
+	    break;
+	}
+
+	case 168:{
+	    /* based on LZ3NY code, by HA2OS
+	       PFX_NUM_MULTIS   (in file or listed in logcfg.dat),
+	       We directly copy it into pfxnummulti_str, then parse the prefixlist
+	       and fill the pfxnummulti array.
+	     */
+
+	    int counter = 0;
+	    int pfxnum;
+	    static char pfxnummulti_str[50] = "";
+	    char parsepfx[15] = "";
+
+	    PARAMETER_NEEDED(teststring);
+	    g_strlcpy(pfxnummulti_str, fields[1], sizeof(pfxnummulti_str));
+	    g_strchomp(pfxnummulti_str);
+
+	    /* creating the array */
+	    tk_ptr = strtok(pfxnummulti_str, ",");
+	    counter = 0;
+
+	    if (tk_ptr != NULL) {
+		while (tk_ptr) {
+		    parsepfx[0] = '\0';
+		    if (isdigit(tk_ptr[strlen(tk_ptr)-1])) {
+			sprintf(parsepfx, "%sAA", tk_ptr);
+		    }
+		    else {
+			sprintf(parsepfx, "%s0AA", tk_ptr);
+		    }
+		    pfxnummulti[counter].countrynr = getctydata(parsepfx);
+		    for(pfxnum=0; pfxnum<10; pfxnum++) {
+			pfxnummulti[counter].qsos[pfxnum] = 0;
+		    }
+		    tk_ptr = strtok(NULL, ",");
+		    counter++;
+		}
+	    }
+	    pfxnummultinr = counter;
+	    setcontest();
+	    break;
+	}
+    case 169:{		        /* wpx style prefixes mult */
+		pfxmultab = 1;	/* enable pfx on all band */
+		break;
+	    }
+
+    case 170 ... 181: {
+    	    PARAMETER_NEEDED(teststring);
+	    strcpy(qtc_recv_msgs[ii - 170], fields[1]);
+	    break;
+	    }
+    case 182 ... 193: {
+    	    PARAMETER_NEEDED(teststring);
+	    strcpy(qtc_send_msgs[ii - 182], fields[1]);
+	    break;
+	    }
+    case 194 ... 207:{	// get QTC recv phone messages
+	    PARAMETER_NEEDED(teststring);
+	    g_strlcpy(qtc_phrecv_message[ii - 194], g_strchomp(fields[1]), 71);
+	    mvprintw(15, 5, "A: QTC RECV phone message #%d is %s", ii - 194, qtc_phrecv_message[ii - 194]);
+	    refreshp();
+	    break;
+	}
+    case 208 ... 221:{	// get QTC send phone messages
+	    PARAMETER_NEEDED(teststring);
+	    g_strlcpy(qtc_phsend_message[ii - 208], g_strchomp(fields[1]), 71);
+	    mvprintw(15, 5, "A: QTC SEND phone message #%d is %s", ii - 208, qtc_phrecv_message[ii - 208]);
+	    refreshp();
+	    break;
+	}
+    case 222: {
+	    qtcrec_record = 1;
+ 	    break;
+    }
+    case 223: {
+	    PARAMETER_NEEDED(teststring);
+	    int p, q = 0, i = 0, s = 0;
+	    for(p=0; p<strlen(fields[1]); p++) {
+	        if (p > 0 && fields[1][p] == ' ') {
+		    s = 1;
+		    qtcrec_record_command_shutdown[p] = '\0';
+		}
+		if (s == 0) {
+		    qtcrec_record_command_shutdown[p] = fields[1][p];
+		}
+		if (fields[1][p] == '$') {
+		    qtcrec_record_command[i][q] = '\0';
+		    i=1;
+		    p++;
+		    q=0;
+		}
+		if (fields[1][p] != '\n') {
+		    qtcrec_record_command[i][q] = fields[1][p];
+		}
+		q++;
+		qtcrec_record_command[i][q] = ' ';
+	    }
+
+	    if (qtcrec_record_command[i][q-1] != '&') {
+		qtcrec_record_command[i][q++] = ' ';
+		qtcrec_record_command[i][q++] = '&';
+	    }
+	    qtcrec_record_command[i][q] = '\0';
+ 	    break;
+    }
+    case 224: {
+	    PARAMETER_NEEDED(teststring);
+	    if (strcmp(fields[1], "CONTINENTLIST")) {
+	        if (strlen(continent_multiplier_list[0]) == 0) {
+		    showmsg
+			("WARNING: you need to set the CONTINENTLIST parameter...");
+		    sleep(5);
+		    exit(1);
+		}
+		exclude_multilist_type = 1;
+	    }
+	    else if (strcmp(fields[1], "COUNTRYLIST")) {
+	        if (strlen(countrylist[0]) == 0) {
+		    showmsg
+			("WARNING: you need to set the COUNTRYLIST parameter...");
+		    sleep(5);
+		    exit(1);
+		}
+		exclude_multilist_type = 2;
+	    }
+	    else {
+	        showmsg
+			("WARNING: choose one of these for EXCLUDE_MULTILIST: CONTINENTLIST, COUNTRYLIST");
+		    sleep(5);
+		    exit(1);
+	    }
+	    break;
+    }
+    case 225:{
+	    PARAMETER_NEEDED(teststring);
+	    strcpy(message[SP_CALL_MSG], fields[1]);
+	    break;	/* end messages */
+	}
+    case 226:{
+		PARAMETER_NEEDED(teststring);
+		g_strlcpy(qtc_cap_calls, g_strchomp(fields[1]),
+			sizeof(exchange_list));
+		break;
+	    }
+    case 227: {
+	    qtc_auto_filltime = 1;
+	    break;
+    }
     default: {
 		KeywordNotSupported(g_strstrip(inputbuffer));
 		break;
