@@ -17,8 +17,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <curses.h>
+#ifndef PRINTCALL_H
+#define PRINTCALL_H
 
 void printcall(void);
 void highlightCall(unsigned int n);
 
+#endif /* PRINTCALL_H */
