@@ -24,18 +24,15 @@
 	 *--------------------------------------------------------------*/
 
 #include "rtty.h"
-#include <ctype.h>
 #include <termios.h>
-#include <curses.h>
-#include <string.h>
-#include <stdio.h>
 #include "startmsg.h"
-#include <stdlib.h>
-#include <unistd.h>
 #include <fcntl.h>
 #include "tlf.h"
 #include "printcall.h"
 #include <glib.h>
+#include "ui_utils.h"
+#include "qtcvars.h"
+
 
 static int fdcont;		// global for this file: tty file descriptor
 static char ry_term[5][50] = { "", "", "", "", "" };
@@ -44,6 +41,7 @@ static char ry_term[5][50] = { "", "", "", "", "" };
 int init_controller()
 {
     extern char controllerport[];
+    extern int keyerport;
 
     struct termios termattribs;
 
@@ -68,15 +66,27 @@ int init_controller()
 
     tcsetattr(fdcont, TCSANOW, &termattribs);	/* Set the serial port */
 
+    if (keyerport == GMFSK) {
+	lseek(fdcont, 0, SEEK_END);
+    }
+
     showstring(controllerport, " opened...\n");
 
     return (fdcont);		// return file descriptor
 }
 
+/* ------------------------- deinit controller -------------------------- */
+void deinit_controller()
+{
+    if (fdcont)
+	close(fdcont);
+}
+
 /* ------------------------  add text to terminal ------------------------ */
 void ry_addchar(char c)
 {
     static int k = 0;
+    int i = 0;
     FILE *ry_fp;
 
     if ((ry_fp = fopen("RTTYlog", "a")) == NULL) {
@@ -99,6 +109,24 @@ void ry_addchar(char c)
 	g_strlcpy(ry_term[3], ry_term[4], 41);
 	ry_term[4][0] = '\0';
 	k = 0;
+
+	if (qtc_ry_capture == 1) {
+	    if (qtc_ry_currline == (QTC_RY_LINE_NR - 1)
+	     && qtc_ry_lines[qtc_ry_currline].content[0] != '\0') {
+		for(i=0; i<(QTC_RY_LINE_NR - 1); i++) {
+		    g_strlcpy(qtc_ry_lines[i].content,
+			      qtc_ry_lines[i+1].content, 41);
+		    qtc_ry_lines[i].attr = qtc_ry_lines[i+1].attr;
+		}
+	    }
+	    else {
+		if (strlen(qtc_ry_lines[qtc_ry_currline].content) > 0) {
+		    qtc_ry_currline++;
+		}
+	    }
+	    qtc_ry_lines[qtc_ry_currline].content[0] = '\0';
+	    qtc_ry_lines[qtc_ry_currline].attr = 0;
+	}
     }
     else {
 	if (iscntrl( c )) {
@@ -114,11 +142,31 @@ void ry_addchar(char c)
 	    g_strlcpy(ry_term[3], ry_term[4], 41);
 	    ry_term[4][0] = '\0';
 	    k = 0;
+
+	    if (qtc_ry_capture == 1) {
+		if (qtc_ry_currline == (QTC_RY_LINE_NR - 1)
+		 && qtc_ry_lines[qtc_ry_currline].content[0] != '\0') {
+		    for(i=0; i<(QTC_RY_LINE_NR - 1); i++) {
+			g_strlcpy(qtc_ry_lines[i].content,
+				  qtc_ry_lines[i+1].content, 41);
+			qtc_ry_lines[i].attr = qtc_ry_lines[i+1].attr;
+		    }
+		}
+		else {
+		    qtc_ry_currline++;
+		}
+		qtc_ry_lines[qtc_ry_currline].content[0] = '\0';
+		qtc_ry_lines[qtc_ry_currline].attr = 0;
+	    }
 	}
+
 	// add char to line
+	if (qtc_ry_capture == 1) {
+	    qtc_ry_lines[qtc_ry_currline].content[k] = c;
+	    qtc_ry_lines[qtc_ry_currline].content[k+1] = '\0';
+	}
 	ry_term[4][k++] = c;
 	ry_term[4][k] = '\0';
-
     }
 }
 
@@ -127,8 +175,6 @@ void ry_addchar(char c)
 
 int show_rtty(void)
 {
-
-    extern int use_rxvt;
     extern int trxmode;
     extern int miniterm;
     extern int commentfield;
@@ -138,10 +184,7 @@ int show_rtty(void)
 	return (-1);
 
     attroff(A_STANDOUT);
-    if (use_rxvt == 0)
-	attron(COLOR_PAIR(C_HEADER) | A_BOLD);
-    else
-	attron(COLOR_PAIR(C_HEADER));
+    attron(modify_attr(COLOR_PAIR(C_HEADER)));
 
     mvprintw(1, 0, "                                        ");
     mvprintw(1, 0, "%s", ry_term[0]);
