@@ -22,8 +22,14 @@
  	*
  	*--------------------------------------------------------------*/
 
+#ifndef RTTY_H
+
+#define RTTY_H
 
 int init_controller() ;
+void deinit_controller();
 int rx_rtty () ;
 int show_rtty(void);
 
+#endif /* end of include guard: RTTY_H */
+
