@@ -16,12 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include "tlf.h"
-#include "qsonr_to_str.h"
-
+#ifndef SCROLL_LOG_H
+#define SCROLL_LOG_H
 
 void scroll_log(void);
 
+#endif /* SCROLL_LOG_H */
