@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2013           Ervin Hegedüs - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,12 +23,24 @@
 	 *--------------------------------------------------------------*/
 
 #include "searchlog.h"
+#include "printcall.h"
+#include "tlf.h"
+#include "nicebox.h"
+#include "zone_nr.h"
+#include "getpx.h"
+#include "showscore.h"
 #include "dxcc.h"
 #include <panel.h>
 #include <glib.h>
 #ifdef HAVE_CONFIG_H
 #	include <config.h>
 #endif
+#include "qtcutil.h"
+#include "getctydata.h"
+#include "ui_utils.h"
+#include "qtcvars.h"
+
+GPtrArray *callmaster = NULL;
 
 PANEL *search_panel;
 WINDOW *search_win;
@@ -36,7 +49,6 @@ int nr_bands;
 
 void show_needed_sections(void);
 
-
 /** Check for all band mode
  *
  * Check if we work real contest (only nonWARC bands allowed)
@@ -89,7 +101,6 @@ static char hiscall_yfk[14] = "            ";
 
 void searchlog(char *searchstring)
 {
-    extern int use_rxvt;
     extern int isdupe;		// LZ3NY auto-b4 patch
     extern int searchflg;
     extern int dupe;
@@ -99,11 +110,13 @@ void searchlog(char *searchstring)
     extern int cqww;
     extern int pacc_pa_flg;
     extern int pacc_qsos[10][10];
+    extern t_pfxnummulti pfxnummulti[MAXPFXNUMMULT];
+    extern int pfxnummultinr;
     extern int countrynr;
     extern int contest;
     extern int wpx;
     extern int arrlss;
-    extern int zones[41];
+    extern int zones[MAX_ZONES];
     extern char pxstr[];
     extern int w_cty;
     extern int ve_cty;
@@ -122,8 +135,6 @@ void searchlog(char *searchstring)
     extern int ignoredupe;
     extern int qso_once;
     extern int trxmode;
-    extern long int nr_callmastercalls;
-    extern char callmasterarray[MAX_CALLMASTER][14];
     extern char qsos[MAX_QSOS][LOGLINELEN+1];
     extern char hiscall[];
     extern char zone_export[];
@@ -131,6 +142,7 @@ void searchlog(char *searchstring)
     extern int show_time;
     extern int wazmult;
     extern int itumult;
+    extern int country_mult;
 
     int srch_index = 0;
     int r_index = 0;
@@ -151,6 +163,11 @@ void searchlog(char *searchstring)
     static int qso_index = 0;
     static int xwin = 1;
     static int ywin = 1;
+    char qtccall[15];	// temp str for qtc search
+    char qtcflags[6] = {' ', ' ', ' ', ' ', ' ', ' '};
+    int pfxnumcntidx;
+
+    struct t_qtc_store_obj *qtc_temp_ptr;
 
     if (!initialized) {
 	InitSearchPanel();
@@ -301,6 +318,9 @@ void searchlog(char *searchstring)
 	werase( search_win );
 
 	wnicebox(search_win, 0, 0, nr_bands, 37, "Worked");
+	if (qtcdirection > 0) {
+	    mvwprintw(search_win, 0, 35, "Q");
+	}
 
 	wattrset(search_win, COLOR_PAIR(C_LOG) | A_STANDOUT );
 	for (i = 0; i < nr_bands; i++)
@@ -377,6 +397,19 @@ void searchlog(char *searchstring)
 		j = 9;
 
 	    if ((j > 0) && (j < 10)) {
+		if (qtcdirection > 0) {
+		    qtccall[0] = '\0';
+		    z = 12;	// first pos of callsign
+		    l = 0;
+		    do {
+			qtccall[l] = s_inputbuffer[z];
+			z++; l++;
+		    } while(s_inputbuffer[z] != ' ');
+		    qtccall[l] = '\0';
+
+		    qtc_temp_ptr = qtc_get(qtccall);
+		    qtcflags[j-1] = qtc_get_value(qtc_temp_ptr);
+		}
 		if ((j < 7) || IsAllBand()) {
 		    mvwprintw(search_win, j, 1, "%s", s_inputbuffer);
 		}
@@ -446,6 +479,14 @@ void searchlog(char *searchstring)
 	/* print worked zones and countrys for each band in checkwindow */
 	wattron(search_win, COLOR_PAIR(C_HEADER) | A_STANDOUT);
 
+	if (qtcdirection > 0) {
+	    for(l=0; l<6; l++) {
+		if (qtcflags[l] != ' ') {
+		    mvwprintw(search_win, l+1, 35, "%c", qtcflags[l]);
+		}
+	    }
+	}
+
 	if (cqww == 1 || contest == 0 || pacc_pa_flg == 1) {
 
 	    if ((countries[countrynr] & BAND10) != 0) {
@@ -545,6 +586,52 @@ void searchlog(char *searchstring)
 
 	    }
 	}
+
+	if ((pfxnummultinr >= 0 || country_mult) && contest == 1) {
+	    getpx(hiscall);
+	    pxnr = pxstr[strlen(pxstr) - 1] - 48;
+
+	    getctydata(hiscall);
+	    pfxnumcntidx = -1;
+	    int tbandidx = -1;
+
+	    if (pfxnummultinr >= 0) {
+		int pfxi = 0;
+		while(countrynr != pfxnummulti[pfxi].countrynr && pfxi < pfxnummultinr) {
+		    pfxi++;
+		}
+		if (pfxnummulti[pfxi].countrynr == countrynr) {
+		    pfxnumcntidx = pfxi;
+		}
+	    }
+	    if (pfxnumcntidx >= 0) {
+		tbandidx = pfxnummulti[pfxnumcntidx].qsos[pxnr];
+	    }
+	    else {
+		tbandidx = countries[countrynr];
+	    }
+
+	    if ((tbandidx & BAND160) == BAND160) {
+		mvwprintw(search_win, 6, 37, "M");
+	    }
+	    if ((tbandidx & BAND80) == BAND80) {
+		mvwprintw(search_win, 5, 37, "M");
+	    }
+	    if ((tbandidx & BAND40) == BAND40) {
+		mvwprintw(search_win, 4, 37, "M");
+	    }
+	    if ((tbandidx & BAND20) == BAND20) {
+		mvwprintw(search_win, 3, 37, "M");
+	    }
+	    if ((tbandidx & BAND15) == BAND15) {
+		mvwprintw(search_win, 2, 37, "M");
+	    }
+	    if ((tbandidx & BAND10) == BAND10) {
+		mvwprintw(search_win, 1, 37, "M");
+	    }
+
+	}
+
 	refreshp();
 
 
@@ -554,10 +641,7 @@ void searchlog(char *searchstring)
 	    l = 0;
 	    j = 0;
 
-	    if (use_rxvt == 0)
-		attron(COLOR_PAIR(C_LOG) | A_BOLD | A_STANDOUT);
-	    else
-		attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+	    attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
 
 	    for (k = 1; k <= 5; k++) {
 		mvprintw(k, 0, "%s",
@@ -597,12 +681,8 @@ void searchlog(char *searchstring)
 			if (dupe == ISDUPE) {
 			    attrset(COLOR_PAIR(C_DUPE));
 			} else {
-			    if (use_rxvt == 0)
-				attron(COLOR_PAIR
-				       (C_BORDER) | A_BOLD | A_STANDOUT);
-			    else
-				attron(COLOR_PAIR
-				       (C_BORDER) | A_STANDOUT);
+			    attron(modify_attr(COLOR_PAIR(C_BORDER) |
+				A_STANDOUT));
 			}
 			mvprintw(xwin + l, ywin + j, "%s ", printres);
 			attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
@@ -627,24 +707,20 @@ void searchlog(char *searchstring)
 	    if (strcmp(hiscall, printres) != 0) {
 
 		/* and now check callmaster database */
-		for (m = 0; m < nr_callmastercalls; m++)
+		for (m = 0; m < callmaster->len; m++)
 		{
 
-		    if ( strstr(callmasterarray[m], hiscall) != NULL ) {
+		    if ( strstr(CALLMASTERARRAY(m), hiscall) != NULL ) {
 
-			if (use_rxvt == 0)
-			    attron(COLOR_PAIR(C_LOG) | A_BOLD |
-				    A_STANDOUT);
-			else
-			    attron(COLOR_PAIR(C_LOG) | A_STANDOUT);
+			attron(modify_attr(COLOR_PAIR(C_LOG) | A_STANDOUT));
 
 			mvprintw(xwin + l, ywin + j, "%s  ",
-				 callmasterarray[m]);
+				 CALLMASTERARRAY(m));
 
 			if (strlen(s_inputbuffercpy) == 0)
-			    strcpy(s_inputbuffercpy, callmasterarray[m]);
+			    strcpy(s_inputbuffercpy, CALLMASTERARRAY(m));
 
-			j += (strlen(callmasterarray[m])) + 1;
+			j += (strlen(CALLMASTERARRAY(m))) + 1;
 
 			if (j >= 30) {
 			    l++;
@@ -660,10 +736,7 @@ void searchlog(char *searchstring)
 
 	    if ((j <= 13) && (l == 0) && (use_part == 1) && (block_part == 0)) {
 
-		if (use_rxvt == 0)
-		    attron(COLOR_PAIR(C_HEADER) | A_BOLD | A_STANDOUT);
-		else
-		    attron(COLOR_PAIR(C_HEADER) | A_STANDOUT);
+		attron(modify_attr(COLOR_PAIR(C_HEADER) | A_STANDOUT));
 
 		mvprintw(13, 0, s_inputbuffercpy);
 		if (strlen(s_inputbuffercpy) > strlen(hiscall)) {
@@ -696,18 +769,24 @@ void searchlog(char *searchstring)
     }
 }
 
+void init_callmaster(void) {
+    if (callmaster)
+	g_ptr_array_free(callmaster, TRUE);
+    callmaster = g_ptr_array_new_full(16000, g_free);
+}
+
 /** loads callmaster database from file
+ * returns number of loaded calls
  */
 int load_callmaster(void)
 {
-    extern char callmasterarray[MAX_CALLMASTER][14];
     extern int arrlss;
 
     FILE *cfp = NULL;
     char callmaster_location[80];
     char s_inputbuffer[186] = "";
-    long int count = 0;
-    int file_ok = 0;
+
+    init_callmaster();
 
     strcpy(callmaster_location, "callmaster");
     if ((cfp = fopen(callmaster_location, "r")) == NULL) {
@@ -719,63 +798,50 @@ int load_callmaster(void)
 	    mvprintw(24, 0, "Error opening callmaster file.\n");
 	    refreshp();
 	    sleep(2);
-	} else
-	    file_ok = 1;
-    } else
-	file_ok = 1;
-
-    if (file_ok == 1) {
-
-	count = 0;
-
-	while ( fgets(s_inputbuffer, 85, cfp) != NULL ) {
-
-	    if ( strlen(s_inputbuffer) < 3 )
-		/* calls are at least 3 char long */
-		continue;
-
-	    if (arrlss == 1) {
-
-		if ((s_inputbuffer[0] == 'A') || (s_inputbuffer[0] == 'K')
-		    || (s_inputbuffer[0] == 'W')
-		    || (s_inputbuffer[0] == 'V')
-		    || (s_inputbuffer[0] == 'C')
-		    || (s_inputbuffer[0] == 'N')) {
-		    s_inputbuffer[strlen(s_inputbuffer) - 1] = '\0';
-
-		    s_inputbuffer[12] = '\0';
-		    strcpy(callmasterarray[count], s_inputbuffer);
-		    count++;
-		}
-
-	    } else {
-
-		if (strlen(s_inputbuffer) > 0)
-		    s_inputbuffer[strlen(s_inputbuffer) - 1] = '\0';
-
-		s_inputbuffer[12] = '\0';
-		strcpy(callmasterarray[count], s_inputbuffer);
-		count++;
-
-	    }
 
+	    return 0;
 	}
-
-	fclose(cfp);
-    } else {
-	if (cfp)
-	    fclose(cfp);
     }
 
-    return (count);
+    while ( fgets(s_inputbuffer, 85, cfp) != NULL ) {
+
+	g_strchomp(s_inputbuffer);
+
+	if (s_inputbuffer[0] == '#')
+	    /* skip comment lines */
+	    continue;
+
+	if ( strlen(s_inputbuffer) < 3 )
+	    /* calls are at least 3 char long */
+	    continue;
+
+	s_inputbuffer[12] = '\0';		/* terminate line length */
+
+	if (arrlss == 1) {
+
+	    /* keep only NA stations */
+	    if ((s_inputbuffer[0] == 'A') || (s_inputbuffer[0] == 'K')
+		|| (s_inputbuffer[0] == 'W')
+		|| (s_inputbuffer[0] == 'V')
+		|| (s_inputbuffer[0] == 'C')
+		|| (s_inputbuffer[0] == 'N')) {
+
+		g_ptr_array_add(callmaster, g_strdup(s_inputbuffer));
+	    }
+	} else {
+
+	    g_ptr_array_add(callmaster, g_strdup(s_inputbuffer));
+	}
+    }
+
+    fclose(cfp);
+    return callmaster->len;
 }
 
 
 /*  --------------------------------------------------------------  */
 void show_needed_sections(void)
 {
-
-    extern int use_rxvt;
     extern int arrlss;
     extern int multarray_nr;
     extern char mults[MAX_MULTS][12];
@@ -787,10 +853,7 @@ void show_needed_sections(void)
     if (arrlss == 1) {
 	cnt = 0;
 
-	if (use_rxvt == 0)
-	    wattron(search_win, COLOR_PAIR(C_WINDOW) | A_BOLD | A_STANDOUT);
-	else
-	    wattron(search_win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+	wattron(search_win, modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
 	for (j = 1; j < 7; j++)
 	    mvwprintw(search_win, j, 1, "                                     ");
@@ -816,11 +879,8 @@ void show_needed_sections(void)
 		if (found != 1) {
 		    mprint[3] = '\0';
 
-		    if (use_rxvt == 0)
-			wattron(search_win, COLOR_PAIR(C_WINDOW) | A_BOLD |
-			       A_STANDOUT);
-		    else
-			wattron(search_win, COLOR_PAIR(C_WINDOW) | A_STANDOUT);
+		    wattron(search_win,
+			modify_attr(COLOR_PAIR(C_WINDOW) | A_STANDOUT));
 
 		    if (strlen(mprint) > 1)
 			mvwprintw(search_win, vert, (hor * 4) + 2, "%s ", mprint);
@@ -841,12 +901,7 @@ void show_needed_sections(void)
 
 void OnLowerSearchPanel(int x, char *str)
 {
-    extern int use_rxvt;
-
-    if (use_rxvt == 0)
-	wattrset(search_win, COLOR_PAIR(C_BORDER) | A_BOLD);
-    else
-	wattrset(search_win, COLOR_PAIR(C_BORDER));
+    wattrset(search_win, modify_attr(COLOR_PAIR(C_BORDER)));
 
     mvwprintw(search_win, 7, x, str);
 }
