@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2014           Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,21 +18,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 #ifndef SENDBUF_H
-
 #define SENDBUF_H
 
-#include<stdlib.h>
-#include<string.h>
-#include <ctype.h>
-#include <sys/types.h>
-#include <curses.h>
-#include "lancode.h"
-#include "tlf.h"
-#include "displayit.h"
-
-extern char buffer[];
-
-void sendbuf(void);
-void sendmessage(char *msg);
+char short_number( char c);
+void sendmessage(const char *msg);
 
 #endif /*  SENDBUF_H */
