@@ -1,7 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2005 Rein Couperus <pa0r@amsat.org>
- *               2012      Thomas Beierlein <tb@forth-ev.de>
+ *               2012,2014      Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,49 +22,78 @@
  	*
  	*--------------------------------------------------------------*/
 
-#include "sendspcall.h" 	
- 	
-int play_file(char *audiofile);
-	
-void sendspcall(void){
+#include "sendspcall.h"
+#include <string.h>
+#include "tlf.h"
+#include "sendbuf.h"
+#include <glib.h>
 
+
+int play_file(char *audiofile);
+
+
+/** prepares your own call in S&P mode
+ *
+ * \return string with prepared call, has to be freed with g_free()
+ *         after use
+ */
+char *PrepareSPcall() {
     extern int demode;
-    extern char buffer[];
     extern char call[];
     extern int trxmode;
     extern int keyerport;
-    extern char ph_message[14][80];
     extern char hiscall[];
 
+    char *buf = g_malloc(80);
+    buf[0] = '\0';
 
     if (trxmode == CWMODE) {
 
 	if (demode ==  SEND_DE )
-	    strcat(buffer, "DE ");
+	    strcat(buf, "DE ");
 
-	strcat(buffer, call);
-	sendbuf();
+	strcat(buf, call);
 
     } else if (trxmode == DIGIMODE) {
 
 	if (keyerport == MFJ1278_KEYER) {
-	    strcat (buffer, "{ ");	/* => ctrl-t */
+	    strcat (buf, "{ ");	/* => ctrl-t */
 	    if (demode ==  SEND_DE) {
-	        strcat(buffer, hiscall);
-		strcat(buffer, " DE ");
+		strcat(buf, hiscall);
+		strcat(buf, " DE ");
 	    }
-	    strcat (buffer, call);
-	    strcat (buffer, "}");	/* => ctrl-r */
+	    strcat (buf, call);
+	    strcat (buf, "}");	/* => ctrl-r */
 	}
 	else {
 	    if (demode ==  SEND_DE ) {
-	        strcat(buffer, hiscall);
-		strcat(buffer, " DE ");
+		strcat(buf, hiscall);
+		strcat(buf, " DE ");
 	    }
-	    strcat(buffer, call);
+	    strcat(buf, call);
 	}
+    }
+    return buf;
+}
 
-	sendbuf();
+
+void sendspcall(void){
+
+    extern int trxmode;
+    extern char message[][80];
+    extern char ph_message[14][80];
+
+    if (trxmode == CWMODE || trxmode == DIGIMODE) {
+
+	/* if set use SPCALL message */
+	if (*message[SP_CALL_MSG] != '\0') {
+	    sendmessage(message[SP_CALL_MSG]);
+	}
+	else { /* otherwise prepare one */
+	    char *SPcall = PrepareSPcall();
+	    sendmessage(SPcall);
+	    g_free(SPcall);
+	}
 
     } else
 
