@@ -16,12 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <curses.h>
-#include "tlf.h"
-#include "nicebox.h"
-
+#ifndef SET_TONE_H
+#define SET_TONE_H
 
 int set_tone(void);
 void write_tone(void);
+
+
+#endif /* end of include guard: SET_TONE_H */
