@@ -16,8 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "tlf.h"
-#include "getctydata.h"
+#ifndef SETCONTEST_H
+#define SETCONTEST_H
 
 int setcontest(void);
 
+#endif /* SETCONTEST_H */
