@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2013           Ervin Hegedüs - HA2OS <airween@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +22,18 @@
 	 *
 	 *--------------------------------------------------------------*/
 #include "setparameters.h"
+#include "tlf.h"
+#include "setcontest.h"
+#include "writeparas.h"
+#include "ui_utils.h"
+#include "getmessages.h"
+#include "checklogfile.h"
+#include "getwwv.h"
+#include "scroll_log.h"
+#include "readcalls.h"
+#include "clear_display.h"
+#include "checkparameters.h"
+
 
 int setparameters(void)
 {
@@ -90,7 +103,7 @@ int setparameters(void)
 
 	refreshp();
 
-	i = onechar();
+	i = key_get();
 
 	if (i == '7') {
 
@@ -148,12 +161,14 @@ int setparameters(void)
 	    mvprintw(4, 2, "pacc_pa   ");
 	    mvprintw(5, 2, "dxped     ");
 	    mvprintw(6, 2, "qso       ");
+	    mvprintw(7, 2, "waedc     ");
 	    mvprintw(1, 12, "  other     ");
 	    mvprintw(2, 12, "            ");
 	    mvprintw(3, 12, "  arrldx_dx ");
 	    mvprintw(4, 12, "  pacc_dx   ");
 	    mvprintw(5, 12, "            ");
 	    mvprintw(6, 12, "            ");
+	    mvprintw(7, 12, "   waedc    ");
 
 	    mvprintw(22, 14, "                    ");
 	    mvprintw(22, 14, "");
