@@ -16,12 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <curses.h>
-#include <string.h>
-#include "tlf.h"
-#include "multiplierinfo.h"
+#ifndef SHOWPXMAP_H
+#define SHOWPXMAP_H
 
 int show_mults(void);
 
+#endif /* SHOWPXMAP_H */
