@@ -28,6 +28,7 @@
 #include "bandmap.h"
 #include "get_time.h"
 #include <pthread.h>
+#include "ui_utils.h"
 
 pthread_mutex_t spot_ptr_mutex = PTHREAD_MUTEX_INITIALIZER;
 
@@ -55,7 +56,7 @@ void addlog(char *s)
     extern struct tln_logline *viewing;
     extern char spot_ptr[MAX_SPOTS][82];
     extern char lastmsg[];
-    extern int ptr;
+    extern int nr_of_spots;
     extern int clusterlog;
 
     int len;
@@ -66,10 +67,10 @@ void addlog(char *s)
 
     for (len = 0; len < strlen(s); len += 80) {
 
-	strncpy(spot_ptr[ptr], s + len, 82);
-	if (strlen(spot_ptr[ptr]) > 5) {
+	strncpy(spot_ptr[nr_of_spots], s + len, 82);
+	if (strlen(spot_ptr[nr_of_spots]) > 5) {
 	    lastmsg[0] = '\0';
-	    strncat(lastmsg, spot_ptr[ptr], 82);
+	    strncat(lastmsg, spot_ptr[nr_of_spots], 82);
 	}
 
 	if (clusterlog == 1) {
@@ -85,14 +86,15 @@ void addlog(char *s)
 	    }
 
 	}
-	ptr++;
+	nr_of_spots++;
 
-	if (ptr > MAX_SPOTS - 1) {
-	    for (ptr = 10; ptr <= MAX_SPOTS - 1; ptr++)
-		strncpy(spot_ptr[ptr - 10], spot_ptr[ptr], 82);
-	    for (ptr = MAX_SPOTS - 1; ptr >= MAX_SPOTS - 11; ptr--)
-		spot_ptr[ptr][0] = '\0';
-	    ptr = MAX_SPOTS - 10;
+	if (nr_of_spots > MAX_SPOTS - 1) {
+	    int idx;
+	    for (idx = 10; idx <= MAX_SPOTS - 1; idx++)
+		strncpy(spot_ptr[idx - 10], spot_ptr[idx], 82);
+	    for (idx = MAX_SPOTS - 1; idx >= MAX_SPOTS - 11; idx--)
+		spot_ptr[idx][0] = '\0';
+	    nr_of_spots = MAX_SPOTS - 10;
 	}
     }
 
@@ -571,7 +573,6 @@ void sanitize(char *s)
 
 void addtext(char *s)
 {
-    extern int use_rxvt;
     extern WINDOW *sclwin;
     extern int in_packetclient;
     extern int lan_active;
@@ -617,10 +618,7 @@ void addtext(char *s)
 	    }
 	    cc += 1;
 
-	    if (use_rxvt == 0)
-		wattron(sclwin, COLOR_PAIR(cc) | A_BOLD);
-	    else
-		wattron(sclwin, COLOR_PAIR(cc));
+	    wattron(sclwin, modify_attr(COLOR_PAIR(cc)));
 
 	}
 
@@ -720,6 +718,7 @@ void addtext(char *s)
 		    && (tln_input_buffer[0] > 32)
 		    && (tln_input_buffer[0] < 126)) {
 		    strncpy(lan_out, tln_input_buffer, 78);
+		    lan_out[78] = '\0';
 		    strcat(lan_out, "\n");
 		    if (strlen(s) == 0)
 			tln_input_buffer[0] = '\0';
@@ -748,7 +747,6 @@ void addtext(char *s)
 
 int init_packet(void)
 {
-
     extern int prsock;
     extern int portnum;
     extern char pr_hostaddress[];
@@ -762,7 +760,6 @@ int init_packet(void)
     extern int packetinterface;
     extern int tnc_serial_rate;
     extern int verbose;
-    extern int use_rxvt;
     extern char tncportname[];
 
     struct termios termattribs;
@@ -774,14 +771,9 @@ int init_packet(void)
 
     tln_input_buffer[0] = '\0';
     attr[NORMAL_ATTR] = A_NORMAL;
-    if (use_rxvt == 0) {
-	attr[MINE_ATTR] = A_BOLD;
-	attr[ENTRY_ATTR] = A_BOLD;
-    } else {
-	attr[MINE_ATTR] = A_NORMAL;
-	attr[ENTRY_ATTR] = A_NORMAL;
+    attr[MINE_ATTR] = modify_attr(A_NORMAL);
+    attr[ENTRY_ATTR] = modify_attr(A_NORMAL);
 
-    }
     addrarg = 0;
 
     if (initialized == 0) {
