@@ -16,10 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include<stdlib.h>
-#include<string.h>
-#include "tlf.h"
+#ifndef STOPTX_H
+#define STOPTX_H
 
 int stoptx(void);
 
+#endif /* STOPTX_H */
