@@ -16,10 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <string.h>
-#include <stdio.h>
-#include<stdlib.h>
-#include "tlf.h"
-
+#ifndef STORE_QSO_H
+#define STORE_QSO_H
 
 int store_qso(char *loglineptr);
+
+#endif /* STORE_QSO_H */
