@@ -16,6 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#ifndef TLF_H
+#define TLF_H
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -29,9 +32,6 @@
 #include <sys/wait.h>
 #include <signal.h>
 
-#ifndef TLF_H
-#define TLF_H
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -131,6 +131,9 @@ enum {
 #define  MAX_MULTS 1000        /* max nr of mults in mults array */
 #define	MAX_SPOTS 200		/* max nr. of spots in spotarray */
 #define MAX_CALLMASTER 50000 /* max number of calls in callmaster array */
+#define CQ_ZONES 40
+#define ITU_ZONES 90
+#define MAX_ZONES (ITU_ZONES + 1) /* size of zones array */
 
 #define EDITOR_JOE 0
 #define EDITOR_VI 1
@@ -139,9 +142,24 @@ enum {
 
 #define LOGLINELEN (88)		/* Length of logline in logfile
 				   (including linefeed) */
-#if defined (TLN_LOGLINE)
-/* do nothing, already defined */
-#else
+/* special message numbers */
+enum {
+    SP_TU_MSG = 12,
+    CQ_TU_MSG = 13,
+    SP_CALL_MSG = 24
+};
+
+/** worked station
+ *
+ * contains all informations about an already worked station */
+struct worked_t {
+    char call[20]; 		/*< call of the station */
+    char exchange[12]; 		/*< the last exchange */
+    int band; 			/*< bitmap for worked bands */
+    int country; 		/*< its country number */
+};
+
+#ifndef TLN_LOGLINE
 #define TLN_LOGLINE
 struct tln_logline {
     struct tln_logline *next;
@@ -151,6 +169,14 @@ struct tln_logline {
 } ;
 #endif
 
+
+#define MAXPFXNUMMULT 30
+typedef struct {
+  int countrynr;
+  int qsos[10];
+} t_pfxnummulti;
+
+
 void refreshp();
 
 #endif /* TLF_H */
