@@ -16,11 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <curses.h>
-#include "tlf.h"
-#include "autocq.h"
+#ifndef WRITE_KEYER_H
+#define WRITE_KEYER_H
 
 int write_keyer(void);
 
+#endif /* WRITE_KEYER_H */
