@@ -24,18 +24,19 @@
 #define _XOPEN_SOURCE 500
 #define _GNU_SOURCE
 #include "writecabrillo.h"
-#include <curses.h>
-#include <stdio.h>
-#include <string.h>
+#include "ui_utils.h"
 #include <glib.h>
-#include <time.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include "getsummary.h"
+#include "tlf.h"
+#include "qtcvars.h"
 
 extern char call[];
-extern int use_rxvt;
 
 /* list of different tags for QSO: line items */
-enum tag_t { NO_ITEM, FREQ, MODE, DATE, TIME, MYCALL, HISCALL, RST_S, RST_R, 
-    EXC_S, EXCH, EXC1, EXC2, EXC3, EXC4, TX };	
+enum tag_t { NO_ITEM, FREQ, MODE, DATE, TIME, MYCALL, HISCALL, RST_S, RST_R, 		// 0...8
+    EXC_S, EXCH, EXC1, EXC2, EXC3, EXC4, TX, QTCRCALL, QTCHEAD, QTCSCALL, QTC };	// 9...19
 
 
 /* conversion table between tag name in format file and internal tag */
@@ -57,7 +58,11 @@ struct tag_conv {
     { "EXC2",	EXC2	},
     { "EXC3",	EXC3	},
     { "EXC4",	EXC4	},
-    { "TX",     TX 	}
+    { "TX",     TX 	},
+    { "QTCRCALL", QTCRCALL	},
+    { "QTCHEAD", QTCHEAD },
+    { "QTCSCALL", QTCSCALL },
+    { "QTC",	QTC }
 };
 
 
@@ -73,6 +78,9 @@ struct cabrillo_desc {
     int item_count;		/* number items in QSO: line */
     GPtrArray *item_array;	/* array of items in QSO: line
     				 * must be from left to right */
+    int qtc_item_count;		/* number items in QTC: line */
+    GPtrArray *qtc_item_array;	/* array of items in QTC: line
+				 * must be from left to right */
 };
 
 
@@ -93,13 +101,20 @@ struct qso_t {
     char *comment;
     float freq;
     int tx;
+    int qtc_serial;
+    int qtc_number;
+    char * qtc_qtime;
+    char * qtc_qcall;
+    char * qtc_qserial;
+    int qtcdirection;
+    int qsots;
 };
 
 int is_comment(char *buffer);
 struct qso_t *get_next_record (FILE *fp);
+struct qso_t *get_next_qtc_record (FILE *fp, int qtcdirection);
 void free_qso(struct qso_t *ptr);
 
-
 /** check if logline is only a comment */
 int is_comment(char *buf) {
 
@@ -109,7 +124,6 @@ int is_comment(char *buf) {
 	return 1;
 }
 
-
 /** get next qso record from log
  *
  * Read next line from logfile until it is no comment.
@@ -129,11 +143,13 @@ struct qso_t *get_next_record (FILE *fp)
     while ((fgets(buffer, sizeof(buffer), fp)) != NULL) {
 
 	if (!is_comment(buffer)) {
-		
+
 	    ptr = g_malloc0 (sizeof(struct qso_t));
 
 	    /* remember whole line */
 	    ptr->logline = g_strdup( buffer );
+	    ptr->qtcdirection = 0;
+	    ptr->qsots = 0;
 
 	    /* split buffer into parts for qso_t record and parse
 	     * them accordingly */
@@ -194,6 +210,110 @@ struct qso_t *get_next_record (FILE *fp)
     return NULL;
 }
 
+/** get next qtc record from log
+ *
+ * Read next line from logfile.
+ * Then parse the received or sent qtc logline into a new allocated received QTC data structure
+ * and return that structure.
+ *
+ * \return ptr to new qtc record (or NULL if eof)
+ */
+struct qso_t *get_next_qtc_record (FILE *fp, int qtcdirection)
+{
+    char buffer[100];
+    char *tmp;
+    char *sp;
+    struct qso_t *ptr;
+    int pos;
+    struct tm date_n_time;
+
+    if (fp == NULL) {
+	return NULL;
+    }
+
+    while ((fgets(buffer, sizeof(buffer), fp)) != NULL) {
+
+
+	ptr = g_malloc0 (sizeof(struct qso_t));
+
+	/* remember whole line */
+	ptr->logline = g_strdup( buffer );
+	ptr->qtcdirection = qtcdirection;
+
+	/* tx */
+	if (qtcdirection == RECV) {
+	    pos = 28;
+	}
+	else {
+	    pos = 33;
+	}
+	ptr->tx = (buffer[pos] == ' ') ? 0 : 1;
+
+	/* split buffer into parts for qso_t record and parse
+	  * them accordingly */
+	tmp = strtok_r( buffer, " \t", &sp);
+
+	/* band */
+	ptr->band = atoi( tmp );
+
+	/* mode */
+	if ( strcasestr( tmp, "CW"))
+	    ptr->mode = CWMODE;
+	else if (strcasestr( tmp, "SSB" ))
+	    ptr->mode = SSBMODE;
+	else
+	    ptr->mode = DIGIMODE;
+
+	/* qso number */
+	ptr->qso_nr = atoi( strtok_r( NULL, " \t", &sp ) );
+
+	/* in case of SEND direction, the 3rd field is the original number of sent QSO,
+	   but it doesn't need for QTC line */
+	if (qtcdirection == SEND) {
+	    tmp = strtok_r( NULL, " \t", &sp );
+	}
+	/* date & time */
+	memset( &date_n_time, 0, sizeof(struct tm) );
+
+	strptime ( strtok_r( NULL, " \t", &sp ), "%d-%b-%y", &date_n_time);
+	strptime ( strtok_r( NULL, " \t", &sp ), "%H:%M", &date_n_time);
+
+	ptr->qsots = timegm(&date_n_time);
+
+	ptr->year = date_n_time.tm_year + 1900;	/* convert to
+							1968..2067 */
+	ptr->month = date_n_time.tm_mon + 1;	/* tm_mon = 0..11 */
+	ptr->day   = date_n_time.tm_mday;
+
+	ptr->hour  = date_n_time.tm_hour;
+	ptr->min   = date_n_time.tm_min;
+
+	if (ptr->tx == 1) {
+	    /* ignore TX if set */
+	    strtok_r( NULL, " \t", &sp );
+	}
+	/* his call */
+	ptr->call = g_strdup( strtok_r( NULL, " \t", &sp ) );
+
+	/* QTC serial and number */
+	ptr->qtc_serial = atoi( strtok_r( NULL, " \t", &sp ) );
+	ptr->qtc_number = atoi( strtok_r( NULL, " \t", &sp ) );
+
+	ptr->qtc_qtime = g_strdup( strtok_r( NULL, " \t", &sp ) );
+	ptr->qtc_qcall = g_strdup( strtok_r( NULL, " \t", &sp ) );
+	ptr->qtc_qserial = g_strdup( strtok_r( NULL, " \t", &sp ) );
+
+	/* frequency */
+	ptr->freq = atof( buffer + 80 );
+	if ( ( ptr->freq < 1800. ) || ( ptr->freq >= 30000. ) ) {
+	    ptr->freq = 0.;
+	}
+
+	return ptr;
+    }
+
+    return NULL;
+}
 
 /** free qso record pointed to by ptr */
 void free_qso(struct qso_t *ptr) {
@@ -201,19 +321,18 @@ void free_qso(struct qso_t *ptr) {
     g_free( ptr->comment );
     g_free( ptr->logline );
     g_free( ptr->call );
+    if (ptr->qtc_qtime != NULL) {
+	g_free( ptr->qtc_qtime );
+	g_free( ptr->qtc_qcall );
+	g_free( ptr->qtc_qserial );
+    }
     g_free( ptr );
-
 }
 
-
 /** write out information */
 void info(char *s)
 {
-    if (use_rxvt == 0)
-        attron(COLOR_PAIR(C_INPUT) | A_STANDOUT | A_BOLD);
-    else
-        attron(COLOR_PAIR(C_INPUT) | A_STANDOUT);
-
+    attron(modify_attr(COLOR_PAIR(C_INPUT) | A_STANDOUT));
     mvprintw(13, 29, "%s", s);
     refreshp();
 }
@@ -251,7 +370,7 @@ enum tag_t translate_item_name( char *name ) {
 }
 
 
-/* parse item describing one entry 
+/* parse item describing one entry
  *
  * has to be in following format: item,length
  *   - item to print (date, time, call, ...)
@@ -267,9 +386,10 @@ struct line_item *parse_line_entry(char *line_entry) {
 
     if ( g_strv_length(parts) == 2 ) {
 	tag = translate_item_name( parts[0] );
+
 	item->tag = tag;
 	item->len = atoi( parts[1] );
-    } 
+    }
     else {
 	/* type is NO_ITEM */
 	item->tag = NO_ITEM;
@@ -291,7 +411,7 @@ struct line_item *parse_line_entry(char *line_entry) {
  * \return 		Pointer to a structure describing the format
  * 			(NULL if file or format not found or not readable)
  */
-struct cabrillo_desc *read_cabrillo_format (char *filename, char *format) 
+struct cabrillo_desc *read_cabrillo_format (char *filename, char *format)
 {
     GKeyFile *keyfile;
     GError *error = NULL;
@@ -299,10 +419,10 @@ struct cabrillo_desc *read_cabrillo_format (char *filename, char *format)
     gsize nrstrings;
     struct cabrillo_desc *cabdesc;
     int i;
-    
+
     keyfile = g_key_file_new();
 
-    if (!g_key_file_load_from_file( keyfile, filename, 
+    if (!g_key_file_load_from_file( keyfile, filename,
 		G_KEY_FILE_NONE, &error)) {
 	g_error_free( error );
 
@@ -320,7 +440,7 @@ struct cabrillo_desc *read_cabrillo_format (char *filename, char *format)
     }
 
     /* read needed keys */
-    list = g_key_file_get_string_list( keyfile, format, 
+    list = g_key_file_get_string_list( keyfile, format,
 			"QSO", &nrstrings, &error );
 
     if ( error && error->code == G_KEY_FILE_ERROR_KEY_NOT_FOUND) {
@@ -336,6 +456,8 @@ struct cabrillo_desc *read_cabrillo_format (char *filename, char *format)
     cabdesc->name = g_strdup(format);
     cabdesc->item_array = g_ptr_array_new();
     cabdesc->item_count = nrstrings;
+    cabdesc->qtc_item_array = NULL;
+    cabdesc->qtc_item_count = 0;
 
     for (i = 0; i < nrstrings; i++) {
 	struct line_item *item;
@@ -357,10 +479,47 @@ struct cabrillo_desc *read_cabrillo_format (char *filename, char *format)
 
     g_strfreev( list );
 
-    /* possible further entries in format specification may contain information 
+    /* read needed QTC keys */
+    list = g_key_file_get_string_list( keyfile, format,
+			"QTC", &nrstrings, &error );
+
+    if ( error && error->code == G_KEY_FILE_ERROR_KEY_NOT_FOUND) {
+
+	/* if not found -> stop processing as that key is optional */
+	g_error_free( error );
+
+    }
+    else {
+
+	/* construct new format descriptor and fill it in */
+	cabdesc->qtc_item_array = g_ptr_array_new();
+	cabdesc->qtc_item_count = nrstrings;
+
+	for (i = 0; i < nrstrings; i++) {
+	    struct line_item *item;
+
+	    item = parse_line_entry( list[i] );
+	    if ( item ) {
+		/* add only well formatted entries */
+		g_ptr_array_add( cabdesc->qtc_item_array, item );
+	    }
+	}
+
+	if ( cabdesc->qtc_item_array->len != nrstrings ) {
+	    /* not all entries are ok -> stop processing */
+	    free_cabfmt( cabdesc );
+	    g_strfreev( list );
+	    g_key_file_free( keyfile );
+	    return NULL;
+	}
+    }
+
+    g_strfreev( list );
+
+    /* possible further entries in format specification may contain information
      * about allowed items for different categories:
      * CONTEST, CATEGORY-OPERATOR, CATEGORY_TRANSMITTER, CATEGORY-POWER,
-     * CATEGORY-ASSISTED, CATEGORY-BAND, CATEGORY-MODE, C-STATION, C-TIME. 
+     * CATEGORY-ASSISTED, CATEGORY-BAND, CATEGORY-MODE, C-STATION, C-TIME.
      * C-OVERLAY
      */
 
@@ -381,7 +540,7 @@ float band2freq(int band) {
     float freq;
 
     switch (band) {
-    	case 160: 
+    	case 160:
 	    freq = 1800.;
 	    break;
 	case 80:
@@ -436,7 +595,7 @@ void add_lpadded( char *dst, char *src, int len ) {
 void add_rpadded( char *dst, char *src, int len ) {
     char *field;
     int l;
-	
+
     field = g_malloc( len + 1);
     strcat( dst, " " );
     memset(field, ' ', len);
@@ -483,15 +642,25 @@ void prepare_line( struct qso_t *qso, struct cabrillo_desc *desc, char *buf ) {
     char tmp[80];
     struct line_item *item;
     gchar *token;
+    int item_count;
+    GPtrArray *item_array;
 
     freq = (int)qso->freq;
     if (freq < 1800.)
 	freq = (int)band2freq( qso->band );
 
-    strcpy( buf, "QSO:" );		/* start the line */
-    for  (i = 0; i < desc->item_count; i++) {
-	item = g_ptr_array_index( desc->item_array, i );
-
+    if (qso->qtcdirection == 0) {
+	strcpy( buf, "QSO:" );		/* start the line */
+	item_count = desc->item_count;
+	item_array = desc->item_array;
+    }
+    else {
+	strcpy( buf, "QTC:" );		/* start the line */
+	item_count = desc->qtc_item_count;
+	item_array = desc->qtc_item_array;
+    }
+    for  (i = 0; i < item_count; i++) {
+	item = g_ptr_array_index( item_array, i );
 	switch (item->tag) {
 	    case FREQ:
 		sprintf( tmp, "%d", freq );
@@ -502,7 +671,7 @@ void prepare_line( struct qso_t *qso, struct cabrillo_desc *desc, char *buf ) {
 		add_lpadded( buf, tmp, item->len );
 		break;
 	    case DATE:
-		sprintf( tmp, "%4d-%02d-%02d", 
+		sprintf( tmp, "%4d-%02d-%02d",
 			qso->year, qso->month, qso->day);
 		add_lpadded( buf, tmp, item->len );
 		break;
@@ -573,6 +742,32 @@ void prepare_line( struct qso_t *qso, struct cabrillo_desc *desc, char *buf ) {
 		sprintf( tmp, "%1d", qso->tx );
 		add_rpadded( buf, tmp, item->len );
 		break;
+	    case QTCRCALL:
+		if (qso->qtcdirection == 1) {	// RECV
+		    strcpy(tmp, call);
+		}
+		if (qso->qtcdirection == 2) {	// SEND
+		    strcpy(tmp, qso->call);
+		}
+		add_rpadded( buf, g_strchomp(tmp), item->len );
+		break;
+	    case QTCHEAD:
+		tmp[0] = '\0';
+		sprintf(tmp, "%*d/%d", 3, qso->qtc_serial, qso->qtc_number);
+		add_rpadded( buf, g_strchomp(tmp), item->len );
+		break;
+	    case QTCSCALL:
+		if (qso->qtcdirection == 1) {	// RECV
+		    strcpy(tmp, qso->call);
+		}
+		if (qso->qtcdirection == 2) {	// SEND
+		    strcpy(tmp, call);
+		}
+		add_rpadded( buf, g_strchomp(tmp), item->len );
+		break;
+	    case QTC:
+		sprintf(tmp, "%s %-14s %s", qso->qtc_qtime, qso->qtc_qcall, qso->qtc_qserial);
+		add_rpadded( buf, g_strchomp(tmp), item->len );
 	    case NO_ITEM:
 	    default:
 		tmp[0] = '\0';
@@ -594,8 +789,9 @@ int write_cabrillo(void)
     char cabrillo_tmp_name[80];
     char buffer[4000] = "";
 
-    FILE *fp1, *fp2;
-    struct qso_t *qso;
+    FILE *fp1, *fp2, *fpqtcrec = NULL, *fpqtcsent = NULL;
+    struct qso_t *qso, *qtcrec = NULL, *qtcsent = NULL;
+    int qsonr, qtcrecnr, qtcsentnr;
 
     if (cabrillo == NULL) {
 	info("Missing CABRILLO= keyword (see man page)");
@@ -631,11 +827,36 @@ int write_cabrillo(void)
 	free_cabfmt( cabdesc );
 	return (1);
     }
+    if (cabdesc->qtc_item_array != NULL) {
+        if (qtcdirection & 1) {
+	    fpqtcrec = fopen(QTC_RECV_LOG, "r");
+	    if (fpqtcrec == NULL) {
+		info("Can't open received QTC logfile.");
+		sleep(2);
+		free_cabfmt( cabdesc );
+		fclose(fp1);
+		return (1);
+	    }
+	}
+        if (qtcdirection & 2) {
+	    fpqtcsent = fopen(QTC_SENT_LOG, "r");
+	    if (fpqtcsent == NULL) {
+		info("Can't open sent QTC logfile.");
+		sleep(2);
+		free_cabfmt( cabdesc );
+		fclose(fp1);
+		if (fpqtcrec != NULL) fclose(fpqtcrec);
+		return (1);
+	    }
+	}
+    }
     if ((fp2 = fopen(cabrillo_tmp_name, "w")) == NULL) {
 	info("Can't create cabrillo file.");
 	sleep(2);
 	free_cabfmt( cabdesc );
-	fclose(fp1);		//added by F8CFE
+	fclose(fp1);
+	if (fpqtcsent != NULL) fclose(fpqtcsent);
+	if (fpqtcrec != NULL) fclose(fpqtcrec);
 	return (2);
     }
 
@@ -647,12 +868,59 @@ int write_cabrillo(void)
 
     info("Writing cabrillo file");
 
+    qsonr = 0;
+    qtcrecnr = 0;
+    qtcsentnr = 0;
     while ((qso = get_next_record(fp1))) {
 
+	qsonr++;
 	prepare_line(qso, cabdesc, buffer);
 
-	if (strlen(buffer) > 5)
+	if (strlen(buffer) > 5) {
 	    fputs(buffer, fp2);
+	}
+	if (fpqtcrec != NULL && qtcrec == NULL) {
+	    qtcrec = get_next_qtc_record(fpqtcrec, RECV);
+	    if (qtcrec != NULL) {
+		qtcrecnr = qtcrec->qso_nr;
+	    }
+	}
+	if (fpqtcsent != NULL && qtcsent == NULL) {
+	    qtcsent = get_next_qtc_record(fpqtcsent, SEND);
+	    if (qtcsent != NULL) {
+		qtcsentnr = qtcsent->qso_nr;
+	    }
+	}
+	while (qtcrecnr == qsonr || qtcsentnr == qsonr) {
+	    if (qtcsent == NULL || (qtcrec != NULL && qtcrec->qsots > qtcsent->qsots)) {
+		prepare_line(qtcrec, cabdesc, buffer);
+		if (strlen(buffer) > 5) {
+		    fputs(buffer, fp2);
+		    free_qso(qtcrec);
+		}
+		qtcrec = get_next_qtc_record(fpqtcrec, RECV);
+		if (qtcrec != NULL) {
+		    qtcrecnr = qtcrec->qso_nr;
+		}
+		else {
+		    qtcrecnr = 0;
+		}
+	    }
+	    else {
+	        prepare_line(qtcsent, cabdesc, buffer);
+		if (strlen(buffer) > 5) {
+		    fputs(buffer, fp2);
+		    free_qso(qtcsent);
+		}
+		qtcsent = get_next_qtc_record(fpqtcsent, SEND);
+		if (qtcsent != NULL) {
+		    qtcsentnr = qtcsent->qso_nr;
+		}
+		else {
+		    qtcsentnr = 0;
+		}
+	    }
+	}
 
 	free_qso(qso);
     }
@@ -661,6 +929,9 @@ int write_cabrillo(void)
 
     fputs("END-OF-LOG:\n", fp2);
     fclose(fp2);
+    if (fpqtcrec != NULL) {
+	fclose(fpqtcrec);
+    }
 
     free_cabfmt( cabdesc );
 
@@ -713,7 +984,7 @@ int write_adif(void)
 	sleep(2);
 	fclose(fp1);		//added by F8CFE
 	return (2);
-    } 
+    }
 
     if (strlen(exchange) > 0)
 	strcpy(standardexchange, exchange);
