@@ -16,16 +16,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include "getsummary.h"
-#include "tlf.h"
-
+#ifndef WRITE_CABRILLO_H
+#define WRITE_CABRILLO_H
 
 int  write_cabrillo(void);
 int  write_adif(void);
+
+#endif /* WRITE_CABRILLO_H */
