@@ -16,9 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "tlf.h"
-#include <stdio.h>
-#include <stdlib.h>
+#ifndef WRITEPARAS_H
+#define WRITEPARAS_H
 
- int writeparas(void);
+int writeparas(void);
 
+#endif /* WRITEPARAS_H */
